# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    GUI,
    MIDAC,
    Acquisition,
    CommandModel,
    DataAnalysis,
    ErrorReporting,
    EventManipulating,
    MSDChem,
    Utilities,
)
from .DataAnalysis import (
    AcqStatus,
    BaseDataWriter,
    CompressionScheme,
    DefaultCalibCoeff,
    Device,
    IBaseDataWriter,
    IBaseNonMSDataWriter,
    IImsFrameMethod,
    ILwMsPeakList,
    IonPolarity,
    LwMsPeak,
    MeasurementType,
    MSActualInfo,
    MSScanType,
    MSTimeSegments,
    RunTimeCalibCoeff,
    ScanDetails,
    ScanHeader,
    SeparationTechnique,
    SpectralPeak,
    SpectrumParams,
    XSamplingType,
)
from .DataAnalysis.IMS import FrameData
from .MIDAC import AbundanceMeasure
from .MSDChem import MSDChemDataMSFile, SpectralRecordType

# Stubs for namespace: Agilent.MassSpectrometry

class AdvancedParamWrapper(System.IDisposable):  # Class
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.AdvancedParamWrapper) -> None: ...
    @overload
    def __init__(self, src: System.IntPtr) -> None: ...
    @overload
    def __init__(self) -> None: ...

    EP1: float
    EP10: float
    EP2: float
    EP3: float
    EP4: float
    EP5: float
    EP6: float
    EP7: float
    EP8: float
    EP9: float

    def Dispose(self) -> None: ...

class AmrtMatch(
    List[Any],
    Sequence[Any],
    Iterable[Any],
    System.Collections.Generic.List[Agilent.MassSpectrometry.IIonMatch],
    Iterable[Agilent.MassSpectrometry.IIonMatch],
    List[Agilent.MassSpectrometry.IIonMatch],
    Sequence[Agilent.MassSpectrometry.IIonMatch],
    Agilent.MassSpectrometry.IAmrtMatch,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.IAmrtMatch) -> None: ...
    def SetMzShiftData(
        self,
        signedZ: int,
        lowestCalcMz: float,
        mzShiftFromCalc: float,
        ionShiftFromNeutral: float,
    ) -> None: ...
    def SetScaleFactor(self, scaleFactor: float) -> None: ...
    def SetIonScores(
        self, mass: float, abund: float, spacing: float, combinedIon: float
    ) -> None: ...
    def SetOverallScore(self, score: float) -> None: ...
    def SetRtScore(self, rtScore: float) -> None: ...

class AmrtScoreCalculator:  # Class
    def __init__(self) -> None: ...
    def ObservedClusterMatchingAPattern(
        self,
        obsSpectrum: Agilent.MassSpectrometry.IMsXyData,
        expIsoPattern: Agilent.MassSpectrometry.IMsXyData,
        groupingParameters: Agilent.MassSpectrometry.IIonGroupingParameters,
        peakExtractParameters: Agilent.MassSpectrometry.IMsPeakExtractParamters,
        keyPeakIdx: int,
    ) -> ILwMsPeakList: ...
    @staticmethod
    def CalculateMassScore(
        measuredMz: float,
        refMz: float,
        deviations: Agilent.MassSpectrometry.IExpectedDeviationParameters,
    ) -> float: ...
    def CombineIonAndRtScores(
        self,
        match: Agilent.MassSpectrometry.IAmrtMatch,
        rtScore: float,
        weightingParameters: Agilent.MassSpectrometry.IScoreWeightingParameters,
    ) -> None: ...
    @overload
    def CalculateAmMatchScores(
        self,
        obsSpectrum: Agilent.MassSpectrometry.IMsXyData,
        calcSpectrum: Agilent.MassSpectrometry.IMsXyData,
        ionFormula: str,
        ionAdducts: str,
        ionLosses: str,
        signedChargeState: int,
        groupingParameters: Agilent.MassSpectrometry.IIonGroupingParameters,
        expectedDeviations: Agilent.MassSpectrometry.IExpectedDeviationParameters,
        weightingParameters: Agilent.MassSpectrometry.IScoreWeightingParameters,
    ) -> Agilent.MassSpectrometry.IAmrtMatch: ...
    @overload
    def CalculateAmMatchScores(
        self,
        obsCluster: ILwMsPeakList,
        calcCluster: Agilent.MassSpectrometry.IMsXyData,
        ionAdducts: str,
        ionLosses: str,
        signedChargeState: int,
        groupingParameters: Agilent.MassSpectrometry.IIonGroupingParameters,
        expectedDeviations: Agilent.MassSpectrometry.IExpectedDeviationParameters,
        weightingParameters: Agilent.MassSpectrometry.IScoreWeightingParameters,
    ) -> Agilent.MassSpectrometry.IAmrtMatch: ...
    def CalculateRtMatchScore(
        self, observedRt: float, expectedRt: float, expectedRtDeviation: float
    ) -> float: ...

class BaselineParamWrapper(System.IDisposable):  # Class
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.BaselineParamWrapper) -> None: ...
    @overload
    def __init__(self, src: System.IntPtr) -> None: ...
    @overload
    def __init__(self) -> None: ...

    ChunkSize: int
    FastBaseline: bool
    FracSkip: float
    FracUse: float
    MinChunks: int
    NumZeroes: int
    Tolerance: float

    def Dispose(self) -> None: ...

class CS_Algorithm(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    CS_Latest: Agilent.MassSpectrometry.CS_Algorithm = ...  # static # readonly

class ChargeStateAssignmentWrapper(
    System.IDisposable, Agilent.MassSpectrometry.IIsotopeGrouper
):  # Class
    def __init__(self) -> None: ...
    @overload
    def SetParameters(
        self,
        grouperAlgorithm: Agilent.MassSpectrometry.CS_Algorithm,
        isotopeModel: Agilent.MassSpectrometry.IsotopeModel,
        minZ: int,
        maxZ: int,
        doDeisotope: bool,
        accuracyC0: float,
        accuracyC1: float,
    ) -> None: ...
    @overload
    def SetParameters(
        self,
        isotopeModel: Agilent.MassSpectrometry.IsotopeModel,
        minZ: int,
        maxZ: int,
        doDeisotope: bool,
        accuracyC0: float,
        accuracyC1: float,
    ) -> None: ...
    @overload
    def AssignChargeStates(
        self, pkId: List[int], pkMz: List[float], pkHt: List[float], pkCs: List[int]
    ) -> int: ...
    @overload
    def AssignChargeStates(
        self,
        pkId: List[int],
        pkMz: List[float],
        pkHt: List[float],
        pkCs: List[int],
        pkCl: List[int],
    ) -> int: ...
    def Dispose(self) -> None: ...
    def SetAllowGapFlag(self, allowGap: bool) -> None: ...

class ContentsXmlReader(Agilent.MassSpectrometry.IContentsXmlWriter):  # Class
    def __init__(self, dataFilePath: str) -> None: ...

    AcqDateTime: System.DateTime  # readonly
    AcqSoftwareVersion: str  # readonly
    AcqStatus: AcqStatus  # readonly
    InstrumentName: str  # readonly
    LockedMode: bool  # readonly
    MeasurementType: MeasurementType  # readonly
    SeparationTechnique: SeparationTechnique  # readonly

    def AcquireLock(self) -> bool: ...
    def ReleaseLock(self) -> None: ...

class DeisotopeOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    NoDeisotoping: Agilent.MassSpectrometry.DeisotopeOption = ...  # static # readonly
    RemoveHigherMzIons: Agilent.MassSpectrometry.DeisotopeOption = (
        ...
    )  # static # readonly
    SumIonAbundance: Agilent.MassSpectrometry.DeisotopeOption = ...  # static # readonly

class ExpectedDeviationParameters(
    Agilent.MassSpectrometry.IExpectedDeviationParameters
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, forMsMs: bool) -> None: ...
    @overload
    def __init__(
        self, src: Agilent.MassSpectrometry.IExpectedDeviationParameters
    ) -> None: ...

class IAmrtMatch(
    List[Agilent.MassSpectrometry.IIonMatch],
    Sequence[Agilent.MassSpectrometry.IIonMatch],
    Iterable[Agilent.MassSpectrometry.IIonMatch],
    Iterable[Any],
):  # Interface
    AbundanceScaleFactor: float  # readonly
    CombinedIonScore: float  # readonly
    HasRtScore: bool  # readonly
    IonAbundanceScore: float  # readonly
    IonSpacingScore: float  # readonly
    MassDiffFromCalcMDa: float  # readonly
    MassDiffFromCalcPpm: float  # readonly
    MassDiffFromObsMDa: float  # readonly
    MassDiffFromObsPpm: float  # readonly
    MassScore: float  # readonly
    OverallScore: float  # readonly
    RtScore: float  # readonly

    def Clone(self) -> Agilent.MassSpectrometry.IAmrtMatch: ...

class IExpectedDeviationParameters(object):  # Interface
    AbundanceDeviationPct: float
    MzDeviationMDa: float
    MzDeviationPpm: float
    RtDeviationMin: float

    def Clone(self) -> Agilent.MassSpectrometry.IExpectedDeviationParameters: ...

class IImsDataWriter(IBaseDataWriter):  # Interface
    SkipWritingProfileTfs: bool

    def WriteFrameMethods(self) -> None: ...
    def WriteScanAndFrameHeaders(self, scanHeader: ScanHeader) -> None: ...
    def WriteDataCom(
        self,
        frameData: FrameData,
        frameActuals: List[MSActualInfo],
        defaultCalibration: DefaultCalibCoeff,
        runtimeMassCalibration: RunTimeCalibCoeff,
        nextScanId: int,
    ) -> None: ...
    def AddFrameMethod(self, frameMethod: IImsFrameMethod) -> None: ...
    def CreateImsDataFile(
        self,
        dataFileName: str,
        imsFrameSchemaFile: str,
        msScanSchemaFile: str,
        bOverwrite: bool,
    ) -> None: ...
    def WriteData(
        self,
        frameData: FrameData,
        frameActuals: List[MSActualInfo],
        defaultCalibration: Agilent.MassSpectrometry.ITofCal,
        runtimeMassCalibration: Agilent.MassSpectrometry.ITofCal,
        nextScanId: int,
    ) -> None: ...
    def UpdateFrameMethod(self, frameMethod: IImsFrameMethod) -> None: ...

class IIonGroupingParameters(object):  # Interface
    IsotopeModel: Agilent.MassSpectrometry.IsotopeModel
    MzSpacingToleranceMDa: float
    MzSpacingTolerancePpm: float

    def Clone(self) -> Agilent.MassSpectrometry.IIonGroupingParameters: ...

class IIonGroupingParametersEx(
    Agilent.MassSpectrometry.IIonGroupingParameters
):  # Interface
    DeisotopeOption: Agilent.MassSpectrometry.DeisotopeOption
    MaxZ: int
    MinZ: int

    def Clone(self) -> Agilent.MassSpectrometry.IIonGroupingParametersEx: ...

class IIonMatch(object):  # Interface
    AbundanceCalc: float
    AbundanceObs: float
    MzCalc: float
    MzDiffFromCalcMDa: float  # readonly
    MzDiffFromCalcPpm: float  # readonly
    MzDiffFromObsMDa: float  # readonly
    MzDiffFromObsPpm: float  # readonly
    MzObs: float

    def Clone(self) -> Agilent.MassSpectrometry.IIonMatch: ...

class IIsotopeGrouper(object):  # Interface
    def SetParameters(
        self,
        isotopeModel: Agilent.MassSpectrometry.IsotopeModel,
        minZ: int,
        maxZ: int,
        doDeisotope: bool,
        accuracyC0: float,
        accuracyC1: float,
    ) -> None: ...
    def AssignChargeStates(
        self,
        pkId: List[int],
        pkMz: List[float],
        pkHt: List[float],
        pkCs: List[int],
        pkCl: List[int],
    ) -> int: ...

class IMsPeakExtractParamters(object):  # Interface
    KeyPeakAbsMzTolerance: float
    KeyPeakAbsThreshold: float
    KeyPeakMzRangeExpansion: float
    MinProfilePeakValley: float

class IMsXyData(object):  # Interface
    AbundArray: List[float]
    CalA: float
    CalTo: float
    IsProfileData: bool
    MaxMz: float  # readonly
    MinMz: float  # readonly
    MzArray: List[float]
    XSamplingType: XSamplingType  # readonly

    def SetTofCalibration(self, tofCal: Agilent.MassSpectrometry.ITofCal) -> None: ...

class IRlzArrayIterator(object):  # Interface
    def FirstBin(self) -> int: ...
    def Reset(self) -> None: ...
    def FullLength(self) -> int: ...
    def Next(self, bin: int, value_: int) -> bool: ...

class IScoreWeightingParameters(object):  # Interface
    IonAbundanceScoreWeight: float
    IonSpacingScoreWeight: float
    MassScoreWeight: float
    RtScoreWeight: float

    def Clone(self) -> Agilent.MassSpectrometry.IScoreWeightingParameters: ...

class ITofCal(object):  # Interface
    def TimeToMass(self, time: float) -> float: ...
    def Equals(self, other: Agilent.MassSpectrometry.ITofCal) -> bool: ...
    def AppendStep(self, step: Agilent.MassSpectrometry.ITofCalStep) -> None: ...
    def FullRecalMinMass(self) -> float: ...
    def MassesToTimes(self, masses: List[float], times: List[float]) -> None: ...
    def Recalibrate(self, times: List[float], masses: List[float]) -> None: ...
    def SetFullRecalibrationLimits(
        self, minMass: float, minMassRange: float
    ) -> None: ...
    def StepCount(self) -> int: ...
    def ClearSteps(self) -> None: ...
    def UpdateStep(
        self, index: int, step: Agilent.MassSpectrometry.ITofCalStep
    ) -> None: ...
    def TimesToMasses(self, times: List[float], masses: List[float]) -> None: ...
    def MassToTime(self, mass: float) -> float: ...
    def NewTradStep(self) -> Agilent.MassSpectrometry.ITofCalStepTrad: ...
    @overload
    def Calibrate(
        self,
        times: List[float],
        masses: List[float],
        calOption: Agilent.MassSpectrometry.TofCalAutomation,
    ) -> None: ...
    @overload
    def Calibrate(self, times: List[float], masses: List[float]) -> None: ...
    def Clone(self) -> Agilent.MassSpectrometry.ITofCal: ...
    def FullRecalMinMassRange(self) -> float: ...
    def GetStep(self, index: int) -> Agilent.MassSpectrometry.ITofCalStep: ...
    def NewPolyStep(self) -> Agilent.MassSpectrometry.ITofCalStepPoly: ...

class ITofCalStep(object):  # Interface
    ...

class ITofCalStepPoly(Agilent.MassSpectrometry.ITofCalStep):  # Interface
    Coefficients: List[float]
    PowerFlags: int
    TMax: float
    TMin: float
    Weighting: Agilent.MassSpectrometry.TofCalWtEnum

    def Clone(self) -> Agilent.MassSpectrometry.ITofCalStepPoly: ...

class ITofCalStepTrad(Agilent.MassSpectrometry.ITofCalStep):  # Interface
    A: float
    To: float
    Weighting: Agilent.MassSpectrometry.TofCalWtEnum

    def Clone(self) -> Agilent.MassSpectrometry.ITofCalStepTrad: ...

class ImsDataWriter(
    IBaseDataWriter,
    System.IDisposable,
    Agilent.MassSpectrometry.IImsDataWriter,
    BaseDataWriter,
    IBaseNonMSDataWriter,
):  # Class
    def __init__(self) -> None: ...
    def WriteTimeSegments(self, msTimeSegments: MSTimeSegments) -> None: ...
    def EndWritingData(self) -> None: ...
    def EndStoringData(self) -> None: ...

class IonGroupingParameters(
    Agilent.MassSpectrometry.IIonGroupingParametersEx,
    Agilent.MassSpectrometry.IIonGroupingParameters,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, src: Agilent.MassSpectrometry.IIonGroupingParametersEx
    ) -> None: ...
    @overload
    def __init__(
        self, src: Agilent.MassSpectrometry.IIonGroupingParameters
    ) -> None: ...

class IonMatch(Agilent.MassSpectrometry.IIonMatch):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.IIonMatch) -> None: ...

class IsotopeDistributionCalculator:  # Class
    def __init__(self) -> None: ...

    NominalMassResolution: float

    def PeakDistribution(
        self, neutralFormula: str, signedCharge: int
    ) -> Agilent.MassSpectrometry.IMsXyData: ...
    def ProfileDistribution(
        self, neutralFormula: str, signedCharge: int
    ) -> Agilent.MassSpectrometry.IMsXyData: ...

class IsotopeModel(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Biological: Agilent.MassSpectrometry.IsotopeModel = ...  # static # readonly
    CommonOrganic: Agilent.MassSpectrometry.IsotopeModel = ...  # static # readonly
    Glycan: Agilent.MassSpectrometry.IsotopeModel = ...  # static # readonly
    Peptidic: Agilent.MassSpectrometry.IsotopeModel = ...  # static # readonly
    Unbiased: Agilent.MassSpectrometry.IsotopeModel = ...  # static # readonly

class LzfCompression(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def CompressToBuffer(
        self, inputArray: List[int], bytesToCompress: int, outputArray: List[int]
    ) -> int: ...
    def DecompressToBuffer(
        self, inputArray: List[int], bytesToDecompress: int, outputArray: List[int]
    ) -> int: ...
    def Dispose(self) -> None: ...

class MSDChemToArcher:  # Class
    def __init__(
        self,
        iWriter: IBaseDataWriter,
        msdchemScanDataFile: MSDChemDataMSFile,
        msdchemSIMDataFile: MSDChemDataMSFile,
    ) -> None: ...
    @staticmethod
    def FindAcquisitionMethodGroups(
        strFullPathToMethod: str,
        acqMSTimesForSIMGroups: System.Collections.Generic.List[float],
        actualTimesForSIMGroups: System.Collections.Generic.List[float],
        ionsForSIMGroups: System.Collections.Generic.List[
            System.Collections.Generic.List[float]
        ],
        labelsForIonsForSIMGroups: System.Collections.Generic.List[
            System.Collections.Generic.List[str]
        ],
    ) -> None: ...
    @staticmethod
    def NewScanDetails(
        i32ScanID: int,
        i32CycleID: int,
        dSpectrumRetentionTime: float,
        spectrumParams: SpectrumParams,
        dBasePeakMZ: float,
        dBasePeakValue: float,
        dTIC: float,
        scanType: MSScanType,
        ionPolarity: IonPolarity,
        actualTimesForSIMGroups: System.Collections.Generic.List[float],
    ) -> ScanDetails: ...
    def TranslateScanByScan(
        self, ionPolarity: IonPolarity, bDataFileHasProfileSpectra: bool
    ) -> None: ...
    @staticmethod
    def TranslateSpectralRecordTypeToMSScanType(
        spectralRecordType: SpectralRecordType,
    ) -> MSScanType: ...
    @staticmethod
    def NewSpectrumParams(
        dMinX: float, dMaxX: float, dMaxY: float
    ) -> SpectrumParams: ...
    @staticmethod
    def NewDevice() -> Device: ...
    @staticmethod
    def NewScanHeader(bDataFileHasProfileSpectra: bool) -> ScanHeader: ...

class MsPeakExtractParameters(
    Agilent.MassSpectrometry.IMsPeakExtractParamters
):  # Class
    def __init__(self) -> None: ...

class MsXyData(Agilent.MassSpectrometry.IMsXyData):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        mzArray: List[float],
        abundArray: List[float],
        isProfile: bool,
        xSamplingType: XSamplingType,
        tofCal: Agilent.MassSpectrometry.ITofCal,
    ) -> None: ...
    @overload
    def __init__(
        self,
        mzArray: List[float],
        abundArray: List[float],
        isProfile: bool,
        xSamplingType: XSamplingType,
        calA: float,
        calTo: float,
    ) -> None: ...
    @overload
    def __init__(self, pkList: ILwMsPeakList) -> None: ...
    @overload
    def __init__(self, pkList: List[SpectralPeak]) -> None: ...

class PeakFilterParamWrapper(System.IDisposable):  # Class
    @overload
    def __init__(
        self, src: Agilent.MassSpectrometry.PeakFilterParamWrapper
    ) -> None: ...
    @overload
    def __init__(self, src: System.IntPtr) -> None: ...
    @overload
    def __init__(self) -> None: ...

    MaxPeakCount: int
    PkHtThresholdAbs: float
    PkHtThresholdDisplay: float
    PkHtThresholdPct: float
    PkSNRThreshold: float
    SummedSpectra: int

    def Clear(self) -> None: ...
    def Dispose(self) -> None: ...

class PeakFinderAlgorithm(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    PF_Latest: Agilent.MassSpectrometry.PeakFinderAlgorithm = ...  # static # readonly

class PeakInfoWrapper(System.IDisposable):  # Class
    @overload
    def __init__(self, src: System.IntPtr) -> None: ...
    @overload
    def __init__(self) -> None: ...

    ApexIdx: int
    ApexY: float
    Area: float
    Center: float
    EndIdx: int
    EndY: float
    Height: float
    StartIdx: int
    StartY: float
    Suspect: int
    Width: float

    def Dispose(self) -> None: ...

class PeakLocateParamWrapper(System.IDisposable):  # Class
    @overload
    def __init__(
        self, src: Agilent.MassSpectrometry.PeakLocateParamWrapper
    ) -> None: ...
    @overload
    def __init__(self, src: System.IntPtr) -> None: ...
    @overload
    def __init__(self) -> None: ...

    MaxSpikeWidth: int
    RequiredValley: float

    def Dispose(self) -> None: ...

class RlzAccumulator:  # Class
    @overload
    def __init__(self, abundMeasure: AbundanceMeasure) -> None: ...
    @overload
    def __init__(
        self,
        abundMeasure: AbundanceMeasure,
        firstArray: Agilent.MassSpectrometry.IRlzArrayIterator,
    ) -> None: ...

    ArrayCount: int  # readonly
    BaseAbundance: int  # readonly
    BaseBin: int  # readonly
    FirstNzBin: int  # readonly
    LastNzBin: int  # readonly
    NumNzPoints: int  # readonly
    Result: Agilent.MassSpectrometry.IRlzArrayIterator  # readonly
    TotalAbund: int  # readonly

    def Add(self, addend: Agilent.MassSpectrometry.IRlzArrayIterator) -> None: ...

class RlzArrayMetrics(System.IDisposable):  # Class
    @overload
    def __init__(
        self,
        firstBin: int,
        firstNzBin: int,
        lastNzBin: int,
        maxValue: int,
        maxValueBin: int,
        numCompactedBytes: int,
        numNzValues: int,
        numValues: int,
        tic: int,
    ) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.RlzArrayMetrics) -> None: ...
    @overload
    def __init__(self) -> None: ...

    FirstBin: int
    FirstNzBin: int
    LastNzBin: int
    MaxValue: int
    MaxValueBin: int
    NumCompactedBytes: int
    NumNzValues: int
    NumValues: int
    Tic: int

    def Dispose(self) -> None: ...

class RlzArrayMetricsL(
    System.IDisposable, Agilent.MassSpectrometry.RlzArrayMetrics
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.RlzArrayMetricsL) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.RlzArrayMetrics) -> None: ...
    @overload
    def __init__(
        self,
        firstBin: int,
        firstNzBin: int,
        lastNzBin: int,
        maxValue: int,
        maxValueBin: int,
        numCompactedBytes: int,
        numNzValues: int,
        numValues: int,
        tic: int,
    ) -> None: ...

    Tic: int

class RlzByteCompression(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def DecompressToBuffer(
        self,
        inputArray: List[int],
        inputArrayOffset: int,
        inputBytes: int,
        outputArray: List[int],
    ) -> int: ...
    def DecompressedSize(self, inputArray: List[int], inputArrayOffset: int) -> int: ...
    def Compress(
        self, firstBin: int, inputArray: List[int], outputArray: List[int]
    ) -> Agilent.MassSpectrometry.RlzArrayMetrics: ...
    def DecompressSpecRecord(
        self, inputArray: List[int], inputArrayOffset: int
    ) -> List[int]: ...
    def CompressToBuffer(
        self, firstBin: int, inputArray: List[int], outputArray: List[int]
    ) -> Agilent.MassSpectrometry.RlzArrayMetrics: ...
    def Dispose(self) -> None: ...
    def Decompress(self, inputArray: List[int], inputOffset: int) -> List[int]: ...

class RlzByteIterator(
    System.IDisposable, Agilent.MassSpectrometry.IRlzArrayIterator
):  # Class
    def __init__(
        self, firstBin: int, compressedArray: List[int], arrayOffsetBytes: int
    ) -> None: ...
    def Reset(self) -> None: ...
    def FirstBin(self) -> int: ...
    def Next(self, bin: int, value_: int) -> bool: ...
    def FullLength(self) -> int: ...
    def Dispose(self) -> None: ...

class RlzIntCompression(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def DecompressToBuffer(
        self, inputArray: List[int], inputBytes: int, outputArray: List[int]
    ) -> int: ...
    def DecompressedSize(self, inputArray: List[int]) -> int: ...
    def Compress(
        self, firstBin: int, inputArray: List[int], outputArray: List[int]
    ) -> Agilent.MassSpectrometry.RlzArrayMetrics: ...
    def CompressToBuffer(
        self, firstBin: int, inputArray: List[int], outputArray: List[int]
    ) -> Agilent.MassSpectrometry.RlzArrayMetrics: ...
    def Dispose(self) -> None: ...
    def Decompress(self, inputArray: List[int]) -> List[int]: ...

class RlzIntIterator(
    System.IDisposable, Agilent.MassSpectrometry.IRlzArrayIterator
):  # Class
    def __init__(
        self, hdrInts: int, firstBin: int, compressedArray: List[int]
    ) -> None: ...
    def Reset(self) -> None: ...
    def FirstBin(self) -> int: ...
    def Next(self, bin: int, value_: int) -> bool: ...
    def FullLength(self) -> int: ...
    def Dispose(self) -> None: ...

class RlzIntIteratorOnByteArray(
    System.IDisposable, Agilent.MassSpectrometry.IRlzArrayIterator
):  # Class
    def __init__(
        self,
        hdrInts: int,
        firstBin: int,
        compressedArray: List[int],
        arrayOffsetBytes: int,
    ) -> None: ...
    def Reset(self) -> None: ...
    def FirstBin(self) -> int: ...
    def Next(self, bin: int, value_: int) -> bool: ...
    def FullLength(self) -> int: ...
    def Dispose(self) -> None: ...

class RlzUtilities:  # Class
    @overload
    @staticmethod
    def RlzScheme(byteArray: List[int], arrayOffsetBytes: int) -> CompressionScheme: ...
    @overload
    @staticmethod
    def RlzScheme(compressedArray: List[int]) -> CompressionScheme: ...
    @overload
    @staticmethod
    def RlzIterator(
        firstBin: int, byteArray: List[int], arrayOffsetBytes: int
    ) -> Agilent.MassSpectrometry.IRlzArrayIterator: ...
    @overload
    @staticmethod
    def RlzIterator(
        firstBin: int, rlzCompressedArray: List[int]
    ) -> Agilent.MassSpectrometry.IRlzArrayIterator: ...

class ScoreWeightingParameters(
    Agilent.MassSpectrometry.IScoreWeightingParameters
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, src: Agilent.MassSpectrometry.IScoreWeightingParameters
    ) -> None: ...

class SharedMSStrings:  # Class
    A4_Paper_Size: str = ...  # static # readonly
    AcqData_Dir: str = ...  # static # readonly
    AcqMethod_Dir: str = ...  # static # readonly
    Acquisition_DirName: str = ...  # static # readonly
    Calibration_Masslist_SchemaFileName: str = ...  # static # readonly
    ChromDirectory_FileExtn: str = ...  # static # readonly
    Chromatogram_FileExtn: str = ...  # static # readonly
    Contents_FileName: str = ...  # static # readonly
    Contents_SchemaFileName: str = ...  # static # readonly
    CustomerHome_Location: str = ...  # static # readonly
    CustomerHome_Location_64: str = ...  # static # readonly
    CustomerHome_RegKeyName: str = ...  # static # readonly
    DAMethod_Dir: str = ...  # static # readonly
    DefaultCalib_FileName: str = ...  # static # readonly
    DefaultCalib_SchemaFileName: str = ...  # static # readonly
    DeviceConfig_FileName: str = ...  # static # readonly
    Devices_FileName: str = ...  # static # readonly
    Devices_SchemaFileName: str = ...  # static # readonly
    IMS_Browser_Dir: str = ...  # static # readonly
    IMS_DefaultCal_InstallLocation: str = ...  # static # readonly
    ImsDefaultCal_FileName: str = ...  # static # readonly
    ImsFrameMeth_FileName: str = ...  # static # readonly
    ImsFrame_BinaryFileName: str = ...  # static # readonly
    ImsFrame_SchemaFileName: str = ...  # static # readonly
    ImsOverrideCal_FileName: str = ...  # static # readonly
    InstallHome_Location: str = ...  # static # readonly
    InstallHome_RegKeyName: str = ...  # static # readonly
    Letter_Paper_Size: str = ...  # static # readonly
    MSActualsDefinition_FileName: str = ...  # static # readonly
    MSActualsDefinition_SchemaFileName: str = ...  # static # readonly
    MSCalibration_FileName: str = ...  # static # readonly
    MSPeak_DataFileName: str = ...  # static # readonly
    MSPeriodicActuals_FileName: str = ...  # static # readonly
    MSProfile_DataFileName: str = ...  # static # readonly
    MSScanActuals_FileName: str = ...  # static # readonly
    MSScan_BinaryFileName: str = ...  # static # readonly
    MSScan_SchemaFileName: str = ...  # static # readonly
    MSScan_XSpecific_FileName: str = ...  # static # readonly
    MSScan_XSpecific_SchemaFileName: str = ...  # static # readonly
    MSTS_XSpecific_FileName: str = ...  # static # readonly
    MSTS_XSpecific_SchemaFileName: str = ...  # static # readonly
    MSTimeSegments_FileName: str = ...  # static # readonly
    MSTimeSegments_SchemaFileName: str = ...  # static # readonly
    MetID_Dir: str = ...  # static # readonly
    MethodAcq_Dir: str = ...  # static # readonly
    MethodDA_Dir: str = ...  # static # readonly
    MethodParamChange_FileName: str = ...  # static # readonly
    MethodParamDefinition_FileName: str = ...  # static # readonly
    MethodParamDefinition_SchemaFileName: str = ...  # static # readonly
    Method_LogName: str = ...  # static # readonly
    Methods_Dir: str = ...  # static # readonly
    MetlinDB_FileExtn: str = ...  # static # readonly
    Pcdl_FileExtn: str = ...  # static # readonly
    Profinder_dir: str = ...  # static # readonly
    QTOF_Default_Calibration_Masslist_FileName: str = ...  # static # readonly
    QTOF_MassLists_InstallLocation: str = ...  # static # readonly
    Qual_Dir: str = ...  # static # readonly
    Quant_Dir: str = ...  # static # readonly
    ReportOutput_DirName: str = ...  # static # readonly
    ReportTemplates_DirName: str = ...  # static # readonly
    Reprocessing_Dir: str = ...  # static # readonly
    Result_Dir: str = ...  # static # readonly
    SpecDirectory_FileExtn: str = ...  # static # readonly
    Spectrum_FileExtn: str = ...  # static # readonly
    UserCalBin_FileName: str = ...  # static # readonly
    UserCalIndex_FileName: str = ...  # static # readonly
    Worklist_FileName: str = ...  # static # readonly

class SharedMSStrings:  # Class
    A4_Paper_Size: str = ...  # static # readonly
    AcqData_Dir: str = ...  # static # readonly
    AcqMethod_Dir: str = ...  # static # readonly
    Acquisition_DirName: str = ...  # static # readonly
    Calibration_Masslist_SchemaFileName: str = ...  # static # readonly
    ChromDirectory_FileExtn: str = ...  # static # readonly
    Chromatogram_FileExtn: str = ...  # static # readonly
    Contents_FileName: str = ...  # static # readonly
    Contents_SchemaFileName: str = ...  # static # readonly
    CustomerHome_Location: str = ...  # static # readonly
    CustomerHome_RegKeyName: str = ...  # static # readonly
    DAMethod_Dir: str = ...  # static # readonly
    DefaultCalib_FileName: str = ...  # static # readonly
    DefaultCalib_SchemaFileName: str = ...  # static # readonly
    DeviceConfig_FileName: str = ...  # static # readonly
    Devices_FileName: str = ...  # static # readonly
    Devices_SchemaFileName: str = ...  # static # readonly
    InstallHome_Location: str = ...  # static # readonly
    InstallHome_RegKeyName: str = ...  # static # readonly
    Letter_Paper_Size: str = ...  # static # readonly
    MSActualsDefinition_FileName: str = ...  # static # readonly
    MSActualsDefinition_SchemaFileName: str = ...  # static # readonly
    MSCalibration_FileName: str = ...  # static # readonly
    MSPeak_DataFileName: str = ...  # static # readonly
    MSPeriodicActuals_FileName: str = ...  # static # readonly
    MSProfile_DataFileName: str = ...  # static # readonly
    MSScanActuals_FileName: str = ...  # static # readonly
    MSScan_BinaryFileName: str = ...  # static # readonly
    MSScan_SchemaFileName: str = ...  # static # readonly
    MSScan_XSpecific_FileName: str = ...  # static # readonly
    MSScan_XSpecific_SchemaFileName: str = ...  # static # readonly
    MSTS_XSpecific_FileName: str = ...  # static # readonly
    MSTS_XSpecific_SchemaFileName: str = ...  # static # readonly
    MSTimeSegments_FileName: str = ...  # static # readonly
    MSTimeSegments_SchemaFileName: str = ...  # static # readonly
    MetID_Dir: str = ...  # static # readonly
    MethodAcq_Dir: str = ...  # static # readonly
    MethodDA_Dir: str = ...  # static # readonly
    MethodParamChange_FileName: str = ...  # static # readonly
    MethodParamDefinition_FileName: str = ...  # static # readonly
    MethodParamDefinition_SchemaFileName: str = ...  # static # readonly
    Method_LogName: str = ...  # static # readonly
    Methods_Dir: str = ...  # static # readonly
    MetlinDB_FileExtn: str = ...  # static # readonly
    Pcdl_FileExtn: str = ...  # static # readonly
    QTOF_Default_Calibration_Masslist_FileName: str = ...  # static # readonly
    QTOF_MassLists_InstallLocation: str = ...  # static # readonly
    Qual_Dir: str = ...  # static # readonly
    Quant_Dir: str = ...  # static # readonly
    ReportOutput_DirName: str = ...  # static # readonly
    ReportTemplates_DirName: str = ...  # static # readonly
    Reprocessing_Dir: str = ...  # static # readonly
    Result_Dir: str = ...  # static # readonly
    SpecDirectory_FileExtn: str = ...  # static # readonly
    Spectrum_FileExtn: str = ...  # static # readonly
    Worklist_FileName: str = ...  # static # readonly

class SharedMSStrings:  # Class
    A4_Paper_Size: str = ...  # static # readonly
    AcqData_Dir: str = ...  # static # readonly
    AcqMethod_Dir: str = ...  # static # readonly
    Acquisition_DirName: str = ...  # static # readonly
    Calibration_Masslist_SchemaFileName: str = ...  # static # readonly
    ChromDirectory_FileExtn: str = ...  # static # readonly
    Chromatogram_FileExtn: str = ...  # static # readonly
    Contents_FileName: str = ...  # static # readonly
    Contents_SchemaFileName: str = ...  # static # readonly
    CustomerHome_Location: str = ...  # static # readonly
    CustomerHome_Location_64: str = ...  # static # readonly
    CustomerHome_RegKeyName: str = ...  # static # readonly
    DAMethod_Dir: str = ...  # static # readonly
    DefaultCalib_FileName: str = ...  # static # readonly
    DefaultCalib_SchemaFileName: str = ...  # static # readonly
    DeviceConfig_FileName: str = ...  # static # readonly
    Devices_FileName: str = ...  # static # readonly
    Devices_SchemaFileName: str = ...  # static # readonly
    IMS_Browser_Dir: str = ...  # static # readonly
    IMS_DefaultCal_InstallLocation: str = ...  # static # readonly
    ImsDefaultCal_FileName: str = ...  # static # readonly
    ImsFrameMeth_FileName: str = ...  # static # readonly
    ImsFrame_BinaryFileName: str = ...  # static # readonly
    ImsFrame_SchemaFileName: str = ...  # static # readonly
    ImsOverrideCal_FileName: str = ...  # static # readonly
    InstallHome_Location: str = ...  # static # readonly
    InstallHome_RegKeyName: str = ...  # static # readonly
    Letter_Paper_Size: str = ...  # static # readonly
    MSActualsDefinition_FileName: str = ...  # static # readonly
    MSActualsDefinition_SchemaFileName: str = ...  # static # readonly
    MSCalibration_FileName: str = ...  # static # readonly
    MSPeak_DataFileName: str = ...  # static # readonly
    MSPeriodicActuals_FileName: str = ...  # static # readonly
    MSProfile_DataFileName: str = ...  # static # readonly
    MSScanActuals_FileName: str = ...  # static # readonly
    MSScan_BinaryFileName: str = ...  # static # readonly
    MSScan_SchemaFileName: str = ...  # static # readonly
    MSScan_XSpecific_FileName: str = ...  # static # readonly
    MSScan_XSpecific_SchemaFileName: str = ...  # static # readonly
    MSTS_XSpecific_FileName: str = ...  # static # readonly
    MSTS_XSpecific_SchemaFileName: str = ...  # static # readonly
    MSTimeSegments_FileName: str = ...  # static # readonly
    MSTimeSegments_SchemaFileName: str = ...  # static # readonly
    MetID_Dir: str = ...  # static # readonly
    MethodAcq_Dir: str = ...  # static # readonly
    MethodDA_Dir: str = ...  # static # readonly
    MethodParamChange_FileName: str = ...  # static # readonly
    MethodParamDefinition_FileName: str = ...  # static # readonly
    MethodParamDefinition_SchemaFileName: str = ...  # static # readonly
    Method_LogName: str = ...  # static # readonly
    Methods_Dir: str = ...  # static # readonly
    MetlinDB_FileExtn: str = ...  # static # readonly
    Pcdl_FileExtn: str = ...  # static # readonly
    Profinder_dir: str = ...  # static # readonly
    QTOF_Default_Calibration_Masslist_FileName: str = ...  # static # readonly
    QTOF_MassLists_InstallLocation: str = ...  # static # readonly
    Qual_Dir: str = ...  # static # readonly
    Quant_Dir: str = ...  # static # readonly
    ReportOutput_DirName: str = ...  # static # readonly
    ReportTemplates_DirName: str = ...  # static # readonly
    Reprocessing_Dir: str = ...  # static # readonly
    Result_Dir: str = ...  # static # readonly
    SpecDirectory_FileExtn: str = ...  # static # readonly
    Spectrum_FileExtn: str = ...  # static # readonly
    UserCalBin_FileName: str = ...  # static # readonly
    UserCalIndex_FileName: str = ...  # static # readonly
    Worklist_FileName: str = ...  # static # readonly

class SharedMSStrings:  # Class
    A4_Paper_Size: str = ...  # static # readonly
    AcqData_Dir: str = ...  # static # readonly
    AcqMethod_Dir: str = ...  # static # readonly
    Acquisition_DirName: str = ...  # static # readonly
    Calibration_Masslist_SchemaFileName: str = ...  # static # readonly
    ChromDirectory_FileExtn: str = ...  # static # readonly
    Chromatogram_FileExtn: str = ...  # static # readonly
    Contents_FileName: str = ...  # static # readonly
    Contents_SchemaFileName: str = ...  # static # readonly
    CustomerHome_Location: str = ...  # static # readonly
    CustomerHome_RegKeyName: str = ...  # static # readonly
    DAMethod_Dir: str = ...  # static # readonly
    DefaultCalib_FileName: str = ...  # static # readonly
    DefaultCalib_SchemaFileName: str = ...  # static # readonly
    DeviceConfig_FileName: str = ...  # static # readonly
    Devices_FileName: str = ...  # static # readonly
    Devices_SchemaFileName: str = ...  # static # readonly
    InstallHome_Location: str = ...  # static # readonly
    InstallHome_RegKeyName: str = ...  # static # readonly
    Letter_Paper_Size: str = ...  # static # readonly
    MSActualsDefinition_FileName: str = ...  # static # readonly
    MSActualsDefinition_SchemaFileName: str = ...  # static # readonly
    MSCalibration_FileName: str = ...  # static # readonly
    MSPeak_DataFileName: str = ...  # static # readonly
    MSPeriodicActuals_FileName: str = ...  # static # readonly
    MSProfile_DataFileName: str = ...  # static # readonly
    MSScanActuals_FileName: str = ...  # static # readonly
    MSScan_BinaryFileName: str = ...  # static # readonly
    MSScan_SchemaFileName: str = ...  # static # readonly
    MSScan_XSpecific_FileName: str = ...  # static # readonly
    MSScan_XSpecific_SchemaFileName: str = ...  # static # readonly
    MSTS_XSpecific_FileName: str = ...  # static # readonly
    MSTS_XSpecific_SchemaFileName: str = ...  # static # readonly
    MSTimeSegments_FileName: str = ...  # static # readonly
    MSTimeSegments_SchemaFileName: str = ...  # static # readonly
    MetID_Dir: str = ...  # static # readonly
    MethodAcq_Dir: str = ...  # static # readonly
    MethodDA_Dir: str = ...  # static # readonly
    MethodParamChange_FileName: str = ...  # static # readonly
    MethodParamDefinition_FileName: str = ...  # static # readonly
    MethodParamDefinition_SchemaFileName: str = ...  # static # readonly
    Method_LogName: str = ...  # static # readonly
    Methods_Dir: str = ...  # static # readonly
    MetlinDB_FileExtn: str = ...  # static # readonly
    Pcdl_FileExtn: str = ...  # static # readonly
    QTOF_Default_Calibration_Masslist_FileName: str = ...  # static # readonly
    QTOF_MassLists_InstallLocation: str = ...  # static # readonly
    Qual_Dir: str = ...  # static # readonly
    Quant_Dir: str = ...  # static # readonly
    ReportOutput_DirName: str = ...  # static # readonly
    ReportTemplates_DirName: str = ...  # static # readonly
    Reprocessing_Dir: str = ...  # static # readonly
    Result_Dir: str = ...  # static # readonly
    SpecDirectory_FileExtn: str = ...  # static # readonly
    Spectrum_FileExtn: str = ...  # static # readonly
    Worklist_FileName: str = ...  # static # readonly

class SpectrumInfoWrapper(System.IDisposable):  # Class
    @overload
    def __init__(self, src: System.IntPtr) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Baseline: float
    MaxY: float
    MinY: float
    Noise: float
    XAtMaxY: float

    def Dispose(self) -> None: ...

class SpectrumParamWrapper(System.IDisposable):  # Class
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.SpectrumParamWrapper) -> None: ...
    @overload
    def __init__(self, src: System.IntPtr) -> None: ...
    @overload
    def __init__(self) -> None: ...

    CalA: float
    CalTo: float
    MaxCountsPerTrans: int
    SaturationThreshold: float
    XIsTime: bool

    def Dispose(self) -> None: ...

class TofCalAutomation(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    FullAuto: Agilent.MassSpectrometry.TofCalAutomation = ...  # static # readonly
    PolyAutoMassWeightedTrad: Agilent.MassSpectrometry.TofCalAutomation = (
        ...
    )  # static # readonly
    PolyAutoTradAsSpecified: Agilent.MassSpectrometry.TofCalAutomation = (
        ...
    )  # static # readonly
    PolyAutoUnweightedTrad: Agilent.MassSpectrometry.TofCalAutomation = (
        ...
    )  # static # readonly

class TofCalWtEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Mass: Agilent.MassSpectrometry.TofCalWtEnum = ...  # static # readonly
    MassInv: Agilent.MassSpectrometry.TofCalWtEnum = ...  # static # readonly
    MassSqInv: Agilent.MassSpectrometry.TofCalWtEnum = ...  # static # readonly
    NoWeighting: Agilent.MassSpectrometry.TofCalWtEnum = ...  # static # readonly
    Time: Agilent.MassSpectrometry.TofCalWtEnum = ...  # static # readonly
    TimeInv: Agilent.MassSpectrometry.TofCalWtEnum = ...  # static # readonly
    TimeSqInv: Agilent.MassSpectrometry.TofCalWtEnum = ...  # static # readonly

class TofPfWrap(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def EnablePsFilters(self, enableFilter: bool) -> None: ...
    def LastSpectrumInformation(
        self,
    ) -> Agilent.MassSpectrometry.SpectrumInfoWrapper: ...
    def SetParameters(
        self,
        spectrum: Agilent.MassSpectrometry.SpectrumParamWrapper,
        baseline: Agilent.MassSpectrometry.BaselineParamWrapper,
        locate: Agilent.MassSpectrometry.PeakLocateParamWrapper,
        filter: Agilent.MassSpectrometry.PeakFilterParamWrapper,
    ) -> None: ...
    @overload
    def FindPeaksLw(
        self,
        xArray: List[float],
        yArray: List[float],
        yFullScale: float,
        minXPeak: float,
        maxXPeak: float,
        doCentroid: bool,
        doWidth: bool,
        doArea: bool,
        zeroBounded: bool,
    ) -> List[LwMsPeak]: ...
    @overload
    def FindPeaksLw(
        self,
        xArray: List[float],
        yArray: List[float],
        yFullScale: float,
        deltaX: float,
        minXPeak: float,
        maxXPeak: float,
        doCentroid: bool,
        doWidth: bool,
        doArea: bool,
    ) -> List[LwMsPeak]: ...
    @overload
    def FindPeaksLw(
        self,
        firstX: float,
        deltaX: float,
        yArray: List[float],
        numPoints: int,
        yFullScale: float,
        minXPeak: float,
        maxXPeak: float,
        doCentroid: bool,
        doWidth: bool,
        doArea: bool,
    ) -> List[LwMsPeak]: ...
    @overload
    def FindPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        yFullScale: float,
        minXPeak: float,
        maxXPeak: float,
        doCentroid: bool,
        doWidth: bool,
        doArea: bool,
        zeroBounded: bool,
    ) -> List[Agilent.MassSpectrometry.PeakInfoWrapper]: ...
    @overload
    def FindPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        yFullScale: float,
        deltaX: float,
        minXPeak: float,
        maxXPeak: float,
        doCentroid: bool,
        doWidth: bool,
        doArea: bool,
    ) -> List[Agilent.MassSpectrometry.PeakInfoWrapper]: ...
    @overload
    def FindPeaks(
        self,
        firstX: float,
        deltaX: float,
        yArray: List[float],
        numPoints: int,
        yFullScale: float,
        minXPeak: float,
        maxXPeak: float,
        doCentroid: bool,
        doWidth: bool,
        doArea: bool,
    ) -> List[Agilent.MassSpectrometry.PeakInfoWrapper]: ...
    def EnableHtCorrection(self, enableCorrection: bool) -> None: ...
    def SetAdvancedParameters(
        self, parms: Agilent.MassSpectrometry.AdvancedParamWrapper
    ) -> None: ...
    def Dispose(self) -> None: ...
    def EnableLbFilters(self, enableFilter: bool) -> None: ...

class WtcCalStepPolynomial(
    Agilent.MassSpectrometry.ITofCalStep,
    System.IDisposable,
    Agilent.MassSpectrometry.ITofCalStepPoly,
):  # Class
    @overload
    def __init__(
        self, source: Agilent.MassSpectrometry.WtcCalStepPolynomial
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Coefficients: List[float]
    MaxTerms: int
    PowerFlags: int
    TMax: float
    TMin: float
    Weighting: Agilent.MassSpectrometry.TofCalWtEnum

    def Dispose(self) -> None: ...
    def Clone(self) -> Agilent.MassSpectrometry.ITofCalStepPoly: ...

class WtcCalStepTraditional(
    Agilent.MassSpectrometry.ITofCalStepTrad,
    System.IDisposable,
    Agilent.MassSpectrometry.ITofCalStep,
):  # Class
    @overload
    def __init__(
        self, source: Agilent.MassSpectrometry.WtcCalStepTraditional
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    A: float
    To: float
    Weighting: Agilent.MassSpectrometry.TofCalWtEnum

    def Dispose(self) -> None: ...
    def Clone(self) -> Agilent.MassSpectrometry.ITofCalStepTrad: ...

class WtcCalibration(
    System.IDisposable, System.ContextBoundObject, Agilent.MassSpectrometry.ITofCal
):  # Class
    @overload
    def __init__(self, source: Agilent.MassSpectrometry.WtcCalibration) -> None: ...
    @overload
    def __init__(self, enableLogging: bool) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def GetStep(self, index: int) -> Agilent.MassSpectrometry.ITofCalStep: ...
    def ClearSteps(self) -> None: ...
    def TimesToMasses(self, times: List[float], masses: List[float]) -> None: ...
    def EndLogging(self) -> None: ...
    def FullRecalMinMassRange(self) -> float: ...
    def MassToTime(self, mass: float) -> float: ...
    def RecalibrateStep2(self, times: List[float], masses: List[float]) -> None: ...
    def Dispose(self) -> None: ...
    def StepCount(self) -> int: ...
    def TimeToMass(self, time: float) -> float: ...
    def NewTradStep(self) -> Agilent.MassSpectrometry.ITofCalStepTrad: ...
    def NewPolyStep(self) -> Agilent.MassSpectrometry.ITofCalStepPoly: ...
    def SetFullRecalibrationLimits(
        self, minMass: float, minMassRange: float
    ) -> None: ...
    def UpdateStep(
        self, index: int, step: Agilent.MassSpectrometry.ITofCalStep
    ) -> None: ...
    @overload
    def Recalibrate(self, times: List[float], masses: List[float]) -> None: ...
    @overload
    def Recalibrate(
        self, times: List[float], masses: List[float], preferA: bool, preferSvd: bool
    ) -> None: ...
    def Equals(self, other: Agilent.MassSpectrometry.ITofCal) -> bool: ...
    @overload
    def Calibrate(
        self,
        times: List[float],
        masses: List[float],
        calOption: Agilent.MassSpectrometry.TofCalAutomation,
    ) -> None: ...
    @overload
    def Calibrate(self, times: List[float], masses: List[float]) -> None: ...
    @overload
    def Calibrate(
        self,
        times: List[float],
        masses: List[float],
        calOption: Agilent.MassSpectrometry.TofCalAutomation,
        preferSvd: bool,
    ) -> None: ...
    def Clone(self) -> Agilent.MassSpectrometry.ITofCal: ...
    def MassesToTimes(self, masses: List[float], times: List[float]) -> None: ...
    def AppendStep(self, step: Agilent.MassSpectrometry.ITofCalStep) -> None: ...
    def FullRecalMinMass(self) -> float: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Dialogs

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import (
    BatchFile,
    ChromatogramPeakLabelType,
    ChromatographyType,
    InstrumentType,
    INumericFormat,
    PlotTitleElement,
    QualifierInfoLabelType,
    QuantitationDataSet,
)
from .Compliance import ICompliance
from .Configuration import NumberFormats
from .ScriptEngine import IScriptEngine
from .Toolbar import IScriptToolHandler, IToolHandler, IToolState
from .UIScriptIF import IScriptScope, IUIState

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils

class AskApplyAnalyzeDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Analyze: bool  # readonly
    Integrate: bool  # readonly
    Quantitate: bool  # readonly

class BatchPropertiesDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    BatchFile: BatchFile

class BindingObjectCollection(
    Iterable[T],
    Generic[T],
    System.ComponentModel.IRaiseItemChangedEvents,
    System.IDisposable,
    Sequence[T],
    System.ComponentModel.IBindingList,
    System.ComponentModel.ICancelAddNew,
    System.ComponentModel.IComponent,
    List[Any],
    System.ComponentModel.BindingList[T],
    List[T],
    Iterable[Any],
    Sequence[Any],
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, container: System.ComponentModel.IContainer) -> None: ...

    BoundObject: T
    Site: System.ComponentModel.ISite

    def OnListChanged(self, e: System.ComponentModel.ListChangedEventArgs) -> None: ...
    def Dispose(self) -> None: ...

    Disposed: System.EventHandler  # Event

class ClipboardUtils:  # Class
    @staticmethod
    def GetDataObject() -> System.Windows.Forms.IDataObject: ...

class ControlBox:  # Class
    HasHelpButtonProperty: System.Windows.DependencyProperty  # static # readonly
    HasMaximizeButtonProperty: System.Windows.DependencyProperty  # static # readonly
    HasMinimizeButtonProperty: System.Windows.DependencyProperty  # static # readonly
    HasSysMenuProperty: System.Windows.DependencyProperty  # static # readonly

    @staticmethod
    def SetHasMaximizeButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def SetHasHelpButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def SetHasMinimizeButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def SetHasSysMenu(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def GetHasHelpButton(element: System.Windows.Window) -> bool: ...
    @staticmethod
    def GetHasMaximizeButton(element: System.Windows.Window) -> bool: ...
    @staticmethod
    def GetHasSysMenu(element: System.Windows.Window) -> bool: ...
    @staticmethod
    def GetHasMinimizeButton(element: System.Windows.Window) -> bool: ...

class DefaultEventManipulatorBase(
    Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.DefaultEventManipulatorBase,
):  # Class
    def __init__(
        self, context: Agilent.MassSpectrometry.EventManipulating.Model.IEventContext
    ) -> None: ...

class EnumItemCollection(
    Sequence[Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.EnumItem[T]],
    Generic[T],
    System.IDisposable,
    Iterable[Any],
    Sequence[Any],
    System.ComponentModel.IComponent,
    List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.EnumItem[T]],
    Iterable[Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.EnumItem[T]],
    List[Any],
    System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.EnumItem[T]
    ],
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, container: System.ComponentModel.IContainer) -> None: ...

    Site: System.ComponentModel.ISite

    def Dispose(self) -> None: ...

    Disposed: System.EventHandler  # Event

class EnumItem(Generic[T]):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, t: T) -> None: ...
    @overload
    def __init__(self, t: T, displayText: str) -> None: ...

    DisplayText: str  # readonly
    Value: T
    ValueText: str  # readonly

    def ToString(self) -> str: ...

class FileUtilities:  # Class
    Ext_CdbFiles: str = ...  # static # readonly
    Ext_ReportMethodFile_Quant: str = ...  # static # readonly
    Ext_ReportMethodFile_Unknowns: str = ...  # static # readonly
    Ext_UnknownsAnalysisFile: str = ...  # static # readonly
    MethodFolderExt: str = ...  # static # readonly
    UnifiedMethod_MethodFile_Quant: str = ...  # static # readonly
    UnifiedMethod_MethodFile_TuneEval: str = ...  # static # readonly
    UnifiedMethod_ReportMethodFile: str = ...  # static # readonly
    UnifiedMethod_ReportMethodPath_Quant: str = ...  # static # readonly
    UnifiedMethod_ReportMethodPath_Unknowns: str = ...  # static # readonly

    BatchFolderExtension: str  # static # readonly
    BinBatchFileExtension: str  # static # readonly
    ColumnsSettingsFileExtension: str  # static # readonly
    ColumnsSettingsFileFilter: str  # static # readonly
    FixedGraphicsFileExtension: str  # static # readonly
    FixedGraphicsFileFilter: str  # static # readonly
    GraphicsSettingsFileExtension: str  # static # readonly
    GraphicsSettingsFileFilter: str  # static # readonly
    LayoutFileExtension: str  # static # readonly
    LayoutFileFilter: str  # static # readonly
    MSLibraryExtensionBin: str  # static # readonly
    MSLibraryExtensionXml: str  # static # readonly
    MethodFileExtension: str  # static # readonly
    MethodFileFilter: str  # static # readonly
    MethodFolderExtension: str  # static # readonly
    NistLibraryFolderExtension: str  # static # readonly
    PDFReportTemplateExtension: str  # static # readonly
    PDFReportUnknownsTemplateExtension: str  # static # readonly
    PatternRefLibraryExtension: str  # static # readonly
    RTCalibrationFileExtension: str  # static # readonly
    RefLibraryExtension: str  # static # readonly
    ReportAuditTrailFileName: str  # static # readonly
    ReportBuilderTemplateExtension: str  # static # readonly
    ReportResultFileName: str  # static # readonly
    ReportTemplatesFolder: str  # static # readonly
    ResultsFolderName: str  # static # readonly
    SampleFolderExtension: str  # static # readonly
    SharedCustomerHome: str  # static # readonly
    XmlBatchFileExtension: str  # static # readonly

    @staticmethod
    def FindBatchFiles(batchFolder: str) -> List[str]: ...
    @staticmethod
    def FindSampleDirectories(batchFolder: str) -> List[str]: ...
    @staticmethod
    def GetBatchFileFilter(includeXml: bool) -> str: ...
    @staticmethod
    def GetBatchFilePath(batchFolder: str, batchFile: str) -> str: ...
    @staticmethod
    def GetResultsFolder(batchFolder: str) -> str: ...
    @overload
    @staticmethod
    def GetFullPathName(path: str) -> str: ...
    @overload
    @staticmethod
    def GetFullPathName(assembly: System.Reflection.Assembly, path: str) -> str: ...
    @overload
    @staticmethod
    def GetFullPathName(basePath: str, path: str) -> str: ...

class HelpUtils:  # Class
    def __init__(self) -> None: ...

    Browse_the_acquisition_method: str  # static # readonly
    Compounds_at_a_Glance_Graphic_Settings_window: str  # static # readonly
    Compounds_at_a_Glance_Manual_Integrate_window1: str  # static # readonly
    HelpRoot: str  # static # readonly
    Method_Error_List_Window: str  # static # readonly
    Overview_Batch_Table_Window: str  # static # readonly
    Overview_Calibration_Curve_Window: str  # static # readonly
    Overview_Compound_Information_Window: str  # static # readonly
    Overview_Compounds_at_a_Glance_Window: str  # static # readonly
    Overview_Method_Tasks_Window: str  # static # readonly
    Overview_Sample_Information_Window: str  # static # readonly
    Overview_Task_Queue_Viewer: str  # static # readonly
    add_or_remove_table_columns: str  # static # readonly
    add_samples_dialog_box: str  # static # readonly
    auto_review_dialog_box: str  # static # readonly
    enter_filter_criteria_dialog_box: str  # static # readonly
    integration_setup_dialog_box: str  # static # readonly
    outliers_dialog_box: str  # static # readonly
    print_preview_dialog_box: str  # static # readonly
    sample_type_dialog_box: str  # static # readonly
    user_validation_and_reason_dialog_box: str  # static # readonly
    welcome: str  # static # readonly

    @overload
    @staticmethod
    def GetSubFolder(isWpf: bool) -> str: ...
    @overload
    @staticmethod
    def GetSubFolder() -> str: ...
    @overload
    @staticmethod
    def ShowQuantHtmlHelp(isWpf: bool, htmlfile: str, topic: str) -> bool: ...
    @overload
    @staticmethod
    def ShowQuantHtmlHelp(htmlfile: str) -> bool: ...
    @staticmethod
    def GuessIsWpf() -> bool: ...

class Localize:  # Class
    @staticmethod
    def LocalizeUltraPrintPreview() -> None: ...
    @staticmethod
    def LocalizeXamDockManager() -> None: ...
    @staticmethod
    def LocalizeUltraGrid() -> None: ...
    @staticmethod
    def LocalizeUltraDockManager() -> None: ...
    @staticmethod
    def LocalizeXamRibbon() -> None: ...
    @staticmethod
    def LocalizeUltraMisc() -> None: ...

class LogfileTraceListener(
    System.IDisposable, System.Diagnostics.TextWriterTraceListener
):  # Class
    def __init__(self, file: str, name: str) -> None: ...

    MAX_LOG_SIZE: int = ...  # static # readonly
    MEGABYTE: int = ...  # static # readonly

    ActiveInstance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.LogfileTraceListener
    )  # static # readonly
    Name: str
    PathName: str  # readonly

    @overload
    @staticmethod
    def Initialize(
        logfileFolderName: str,
        logfilePrefix: str,
        traceName: str,
        throwExceptionOnError: bool,
        args: List[str],
    ) -> bool: ...
    @overload
    @staticmethod
    def Initialize(
        logfilePath: str, traceName: str, throwExceptionOnError: bool, args: List[str]
    ) -> bool: ...
    def WriteLine(self, message: str) -> None: ...
    @staticmethod
    def Cleanup(traceName: str) -> None: ...
    @staticmethod
    def ShowLogFolder() -> None: ...
    def DumpCompressedFile(self) -> str: ...
    @staticmethod
    def GetLogfilePath(logfileFolderName: str, filenamePrefix: str) -> str: ...
    @staticmethod
    def ShowCurrentLog() -> None: ...

class MolStructureViewer(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    IsValid: bool  # readonly

    def Initialize(self) -> bool: ...
    def CreateMetafile(
        self,
        graphics: System.Drawing.Graphics,
        moldata: str,
        rect: System.Drawing.Rectangle,
        stream: System.IO.Stream,
    ) -> System.Drawing.Imaging.Metafile: ...
    def DrawStructure(
        self, graphics: System.Drawing.Graphics, moldata: str
    ) -> None: ...
    def Draw(
        self,
        graphics: System.Drawing.Graphics,
        moldata: str,
        color: System.Drawing.Color,
        rect: System.Drawing.Rectangle,
    ) -> None: ...
    def Dispose(self) -> None: ...

class NewBatchHelper(System.IDisposable):  # Class
    @overload
    @staticmethod
    def Do(uiState: IUIState) -> bool: ...
    @overload
    @staticmethod
    def Do(
        uiState: IUIState,
        batchFolder: str,
        batchFile: str,
        auditTrail: bool,
        askSave: bool,
    ) -> bool: ...
    def Dispose(self) -> None: ...

class NumericFormat(INumericFormat):  # Class
    def __init__(
        self, instrumentType: InstrumentType, formats: NumberFormats
    ) -> None: ...

class OpenBatchHelper(System.IDisposable):  # Class
    @overload
    @staticmethod
    def Do(uiState: IUIState) -> bool: ...
    @overload
    @staticmethod
    def Do(uiState: IUIState, batchFolder: str, batchFile: str) -> bool: ...
    @overload
    @staticmethod
    def Do(
        uiState: IUIState, batchFolder: str, batchFile: str, readOnly: bool
    ) -> bool: ...
    @overload
    @staticmethod
    def Do(
        uiState: IUIState,
        batchFolder: str,
        batchFile: str,
        revisionNumber: str,
        readOnly: bool,
    ) -> bool: ...
    def Dispose(self) -> None: ...

class PeakInfo:  # Class
    def __init__(
        self,
        compound: QuantitationDataSet.TargetCompoundRow,
        peak: QuantitationDataSet.PeakRow,
        tic: Agilent.MassSpectrometry.DataAnalysis.IFXData,
    ) -> None: ...

    Area: Optional[float]  # readonly
    CalculatedConcentration: Optional[float]  # readonly
    CompoundGroup: str  # readonly
    CompoundName: str  # readonly
    ConcentrationUnits: str  # readonly
    End: Optional[float]  # readonly
    ExpectedRetentionTime: Optional[float]  # readonly
    FinalConcentration: Optional[float]  # readonly
    Height: Optional[float]  # readonly
    IsSpectralSummer: bool  # readonly
    ManuallyIntegrated: bool  # readonly
    MaxY: Optional[float]  # readonly
    QValueComputed: Optional[int]  # readonly
    RetentionTime: Optional[float]  # readonly
    SignalToNoise: Optional[float]  # readonly
    Start: Optional[float]  # readonly
    TargetResponse: Optional[float]  # readonly
    Y: Optional[float]  # readonly

class PlotPageSettings:  # Class
    def __init__(self) -> None: ...

    Height: float
    MarginBottom: float
    MarginLeft: float
    MarginRight: float
    MarginTop: float
    Scale: float
    Width: float
    Zoom: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintPlotZoomType

    def GetConfigurationString(self) -> str: ...
    def LoadConfiguration(self, str: str) -> None: ...
    def ShowPageSetupDialog(
        self,
        control: System.Windows.Forms.Control,
        settings: System.Drawing.Printing.PrinterSettings,
        isMetric: bool,
    ) -> bool: ...
    @staticmethod
    def ToDialogUnit(inch: float, isMetric: bool) -> int: ...
    @staticmethod
    def FromDialogUnit(val: int, isMetric: bool) -> float: ...
    @staticmethod
    def LoadConfigurationString(
        str: str,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PlotPageSettings
    ): ...
    def DoDefault(self) -> None: ...

class PlotPrintDocument(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDocument,
    System.ComponentModel.IComponent,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        plot: Agilent.MassSpectrometry.GUI.Plot.PlotControl,
        printerSettings: System.Drawing.Printing.PrinterSettings,
        pageSettings: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PlotPageSettings,
        preview: bool,
    ) -> None: ...

    PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly

class PlotUtils:  # Class
    @staticmethod
    def ConstructChromatogramTitle(
        formats: INumericFormat,
        srow: QuantitationDataSet.BatchRow,
        crow: QuantitationDataSet.TargetCompoundRow,
        backgroundSubtracted: bool,
        psext: Agilent.MassSpectrometry.DataAnalysis.IPSetExtractChrom,
        fxdata: Agilent.MassSpectrometry.DataAnalysis.IFXData,
        elements: List[PlotTitleElement],
    ) -> str: ...
    @staticmethod
    def PutEnhMetafileOnClipboard(
        hWnd: System.IntPtr, mf: System.Drawing.Imaging.Metafile
    ) -> bool: ...
    @staticmethod
    def PutPaneImageOnClipboard(
        panes: List[Agilent.MassSpectrometry.GUI.Plot.Pane],
        dataobj: System.Windows.Forms.DataObject,
    ) -> None: ...
    @overload
    @staticmethod
    def GeneratePeakLabel(
        builder: System.Text.StringBuilder,
        info: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PeakInfo,
        types: List[ChromatogramPeakLabelType],
        instrumentType: InstrumentType,
        formats: Agilent.MassHunter.Quantitative.UIModel.INumberFormats,
        peakLabelCaption: bool,
        peakLabelUnits: bool,
    ) -> None: ...
    @overload
    @staticmethod
    def GeneratePeakLabel(
        builder: System.Text.StringBuilder,
        types: List[ChromatogramPeakLabelType],
        format: str,
        instrumentType: InstrumentType,
        formats: Agilent.MassHunter.Quantitative.UIModel.INumberFormats,
        area: Optional[float],
        compoundName: str,
        height: Optional[float],
        retentionTime: Optional[float],
        expectedRetentionTime: Optional[float],
        calculatedConcentration: Optional[float],
        finalConcentration: Optional[float],
        signalToNoise: Optional[float],
        showLabelUnits: bool,
        concentrationUnit: str,
        retentionTimeUnit: str,
        manualIntegrated: Optional[bool],
        compoundGroup: str,
        qValueComputed: Optional[int],
    ) -> None: ...
    @staticmethod
    def SetPaneExtents(
        pane: Agilent.MassSpectrometry.GUI.Plot.Pane,
        graphics: Agilent.MassSpectrometry.GUI.Plot.IGraphics,
    ) -> None: ...
    @staticmethod
    def GetQualifierAnnotation(
        qualifierResponseRatio: Optional[float],
        qualifierResponse: Optional[float],
        targetResponse: Optional[float],
        expectedRelativeResponse: Optional[float],
        qualifierRangeMin: Optional[float],
        qualifierRangeMax: Optional[float],
        instrumentType: InstrumentType,
        formats: Agilent.MassHunter.Quantitative.UIModel.INumberFormats,
        labelType: QualifierInfoLabelType,
    ) -> str: ...

class PrintDataGridViewDocument(
    System.IDisposable,
    System.ComponentModel.IComponent,
    System.Drawing.Printing.PrintDocument,
):  # Class
    def __init__(self, grid: System.Windows.Forms.DataGridView) -> None: ...

    CurrentPage: int  # readonly
    TotalPages: int  # readonly

    def PrintPage(
        self,
        e: System.Drawing.Printing.PrintPageEventArgs,
        marginY: int,
        printPageNumber: bool,
    ) -> None: ...
    def Clear(self) -> None: ...
    def InitPages(
        self,
        graphics: System.Drawing.Graphics,
        rect: System.Drawing.Rectangle,
        initialMargin: int,
    ) -> None: ...

class PrintDataGridViewUtil:  # Class
    @staticmethod
    def PrintPreview(
        grid: System.Windows.Forms.DataGridView,
        documentName: str,
        printerSettings: System.Drawing.Printing.PrinterSettings,
        pageSettings: System.Drawing.Printing.PageSettings,
    ) -> None: ...
    @staticmethod
    def Print(
        grid: System.Windows.Forms.DataGridView,
        displayDialogs: bool,
        documentName: str,
        printerSettings: System.Drawing.Printing.PrinterSettings,
        pageSettings: System.Drawing.Printing.PageSettings,
    ) -> None: ...

class PrintGraphicsDialogResult(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Apply: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDialogResult
    ) = ...  # static # readonly
    Cancel: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDialogResult
    ) = ...  # static # readonly
    Error: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDialogResult
    ) = ...  # static # readonly
    Print: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDialogResult
    ) = ...  # static # readonly

class PrintGraphicsDocument(
    System.IDisposable,
    System.ComponentModel.IComponent,
    System.Drawing.Printing.PrintDocument,
):  # Class
    def __init__(
        self,
        printerSettings: System.Drawing.Printing.PrinterSettings,
        pageSettings: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PlotPageSettings,
        preview: bool,
    ) -> None: ...

    PageRangeCount: int
    PageSettings: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PlotPageSettings
    )  # readonly
    Preview: bool  # readonly

    def PageTo(self, i: int) -> int: ...
    def GetNumPages(self) -> int: ...
    def PageFrom(self, i: int) -> int: ...
    def SetPageTo(self, i: int, page: int) -> None: ...
    def ShowPrintDialog(
        self, isMetric: bool
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDialogResult
    ): ...
    @staticmethod
    def GetRealMarginBounds(
        marginBounds: System.Drawing.RectangleF, g: System.Drawing.Graphics
    ) -> System.Drawing.RectangleF: ...
    def SetPageFrom(self, i: int, page: int) -> None: ...

class PrintPlotZoomType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AdjustTo: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintPlotZoomType
    ) = ...  # static # readonly
    FitTo: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintPlotZoomType
    ) = ...  # static # readonly
    FitToSheet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintPlotZoomType
    ) = ...  # static # readonly
    FitToSheetWidth: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintPlotZoomType
    ) = ...  # static # readonly

class PrintUtils:  # Class
    PageSettings: System.Drawing.Printing.PageSettings  # static # readonly
    PrinterSettings: System.Drawing.Printing.PrinterSettings  # static # readonly

    @staticmethod
    def PrintPreviewGrid(grid: Infragistics.Win.UltraWinGrid.UltraGrid) -> None: ...
    @overload
    @staticmethod
    def PrintPreviewPlot(
        document: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PlotPrintDocument,
        isMetric: bool,
    ) -> None: ...
    @overload
    @staticmethod
    def PrintPreviewPlot(
        document: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDocument,
        parent: System.Windows.Forms.Control,
        isMetric: bool,
    ) -> None: ...
    @staticmethod
    def PrintGrid(
        displayDialog: bool, grid: Infragistics.Win.UltraWinGrid.UltraGrid
    ) -> None: ...
    @staticmethod
    def PrintFile(path: str, printer: str) -> None: ...
    @staticmethod
    def PageSetup(
        parent: System.Windows.Forms.IWin32Window,
        pageSettings: System.Drawing.Printing.PageSettings,
        printerSettings: System.Drawing.Printing.PrinterSettings,
    ) -> System.Windows.Forms.DialogResult: ...
    @staticmethod
    def PrintPreview(
        document: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDocument,
        parent: System.Windows.Forms.Control,
        isMetric: bool,
    ) -> None: ...
    @staticmethod
    def PrintPDF(path: str, printer: str) -> bool: ...
    @staticmethod
    def PrintPlot(
        document: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDocument,
        showDialog: bool,
        isMetric: bool,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDialogResult
    ): ...

    # Nested Types

    class PrintPreviewDialog(
        Infragistics.Win.Printing.UltraPrintPreviewDialog,
        System.Windows.Forms.Layout.IArrangedElement,
        System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
        System.Windows.Forms.IContainerControl,
        System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
        System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
        System.Windows.Forms.IBindableComponent,
        System.Windows.Forms.IDropTarget,
        System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
        Infragistics.Shared.IUltraLicensedComponent,
        System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
        System.Windows.Forms.UnsafeNativeMethods.IOleControl,
        System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
        System.Windows.Forms.IWin32Window,
        System.ComponentModel.IComponent,
        System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
        System.Windows.Forms.UnsafeNativeMethods.IPersist,
        System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
        System.Windows.Forms.ISupportOleDropSource,
        System.Windows.Forms.UnsafeNativeMethods.IOleObject,
        System.Windows.Forms.UnsafeNativeMethods.IViewObject,
        System.IDisposable,
        System.ComponentModel.ISynchronizeInvoke,
    ):  # Class
        def __init__(self) -> None: ...

        PrintAfter: bool

    class RECT:  # Struct
        Bottom: int
        Left: int
        Right: int
        Top: int

class ReportUtils:  # Class
    @staticmethod
    def SetupContext(
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        compliance: ICompliance,
    ) -> None: ...

class SaveBatchAsHelper(System.IDisposable):  # Class
    @overload
    @staticmethod
    def Do(uiState: IUIState) -> bool: ...
    @overload
    @staticmethod
    def Do(uiState: IUIState, batchFolder: str, batchFile: str) -> bool: ...
    def Dispose(self) -> None: ...

class SaveCloseBatchHelper(System.IDisposable):  # Class
    @staticmethod
    def Close(uiState: IUIState) -> bool: ...
    @staticmethod
    def AskSaveClose(uiState: IUIState) -> bool: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def AskSave(uiState: IUIState) -> bool: ...
    @staticmethod
    def Save(uiState: IUIState) -> bool: ...

class SaveExitMethodHelper(System.IDisposable):  # Class
    @staticmethod
    def AskSaveExit(uiState: IUIState) -> bool: ...
    @staticmethod
    def AskMethodFilePath(uiState: IUIState) -> str: ...
    @staticmethod
    def Validate(uiState: IUIState, canContinueWithValidateError: bool) -> bool: ...
    @staticmethod
    def AskSaveClose(uiState: IUIState) -> bool: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def AskSave(uiState: IUIState) -> bool: ...
    @staticmethod
    def Exit(uiState: IUIState) -> bool: ...

class ScriptControl(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    Agilent.MassHunter.Quantitative.UIModel.IScriptPane,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

    CanCopy: bool  # readonly
    CanPaste: bool  # readonly

    def Initialize(self, engine: IScriptEngine) -> None: ...
    def Copy(self) -> None: ...
    def Clear(self) -> None: ...
    def Paste(self) -> None: ...
    def Run(self) -> None: ...

class ScriptFile(System.IDisposable):  # Class
    def __init__(self, path: str) -> None: ...

    Description: str  # readonly
    Language: str  # readonly
    Name: str  # readonly
    PathName: str  # readonly

    def GetReferences(self) -> List[str]: ...
    def GetCompliance(self) -> List[str]: ...
    def GetImports(self) -> List[str]: ...
    def IsComplianceSupported(self, compliance: str) -> bool: ...
    @overload
    @staticmethod
    def ParseOptions() -> None: ...
    @overload
    @staticmethod
    def ParseOptions(
        path: str,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.ScriptFile: ...
    @overload
    @staticmethod
    def ParseOptions(
        reader: System.IO.TextReader,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.ScriptFile: ...
    def Dispose(self) -> None: ...

class ScriptFileCollection(
    Iterable[Any],
    System.IDisposable,
    Iterable[Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.ScriptFile],
):  # Class
    def __init__(self, scriptDir: str) -> None: ...

    Count: int  # readonly
    Extension: str  # static # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.ScriptFile: ...
    def Initialize(self) -> None: ...
    def Dispose(self) -> None: ...

class ScriptToolHandler(IScriptToolHandler, IToolHandler):  # Class
    @overload
    def __init__(
        self, scope: IScriptScope, module: str, state: str, execute: str
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    ExecuteExpression: str
    Module: str
    Scope: IScriptScope  # readonly
    SetStateExpression: str

    def Execute(self, toolState: IToolState, objUiState: Any) -> None: ...
    def SetState(self, toolState: IToolState, objUiState: Any) -> None: ...

class ScriptUtils:  # Class
    @staticmethod
    def InitScript(
        nameSpace: str,
        className: str,
        commandAssemblies: List[System.Reflection.Assembly],
        referenceAssemblies: List[str],
    ) -> System.Reflection.Assembly: ...

class SelectedMzMarker(Agilent.MassSpectrometry.GUI.Plot.Marker):  # Class
    def __init__(
        self,
        size: int,
        lineColor: System.Drawing.Color,
        fillColor: System.Drawing.Color,
    ) -> None: ...
    def Draw(self, plotPane: Agilent.MassSpectrometry.GUI.Plot.PlotPane) -> None: ...

class ShowWaitCursor(System.IDisposable):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, parent: System.Windows.Forms.IWin32Window) -> None: ...
    @overload
    def __init__(self, ctrl: System.Windows.Forms.Control) -> None: ...
    def Dispose(self) -> None: ...

class SpectrumTransfer(
    Agilent.MassHunter.Quantitative.UIModel.ISpectrumTransfer
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, spectrum: Agilent.MassSpectrometry.DataAnalysis.ISpectrum
    ) -> None: ...
    @overload
    def __init__(
        self, component: Agilent.MassSpectrometry.DataAnalysis.Component, title: str
    ) -> None: ...
    @overload
    def __init__(
        self, xvalues: List[float], yvalues: List[float], title: str
    ) -> None: ...
    @overload
    def __init__(
        self,
        library: Agilent.MassSpectrometry.DataAnalysis.INistLibrarySearch,
        specid: Agilent.MassSpectrometry.DataAnalysis.ISpectrumId,
    ) -> None: ...
    @overload
    def __init__(
        self,
        transfer: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.SpectrumTransfer,
    ) -> None: ...

    AcquiredMassRangeMinimum: Optional[float]
    ChromatographyType: Optional[ChromatographyType]
    CollisionEnergy: Optional[float]
    Count: int  # readonly
    InstrumentType: str
    IonPolarity: Optional[Agilent.MassSpectrometry.DataAnalysis.IonPolarity]
    IonizationEnergy: Optional[float]
    IonizationMode: Optional[Agilent.MassSpectrometry.DataAnalysis.IonizationMode]
    IsAccurateMass: bool
    Origin: str
    Owner: str
    PeakCount: int  # readonly
    RetentionTime: Optional[float]
    SampleId: str
    ScanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType]
    SelectedMz: Optional[float]
    SignalToNoise: Optional[float]
    Title: str
    XValues: List[float]  # readonly
    YValues: List[float]  # readonly

    def GetPeakY(self, index: int) -> float: ...
    def GetMaxX(self) -> Optional[float]: ...
    def Normalize(self, max: float) -> None: ...
    def GetX(self, index: int) -> float: ...
    def GetY(self, index: int) -> float: ...
    def GetBasePeak(self, x: Optional[float], y: Optional[float]) -> None: ...
    def GetMinX(self) -> Optional[float]: ...
    def Clone(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.SpectrumTransfer
    ): ...
    def GetPeakX(self, index: int) -> float: ...

class SpectrumUtils:  # Class
    @staticmethod
    def SynthesizeSpectrum(
        informula: str, speciesFormula: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.SpectrumTransfer
    ): ...
    @staticmethod
    def ValidateSpecies(species: str) -> None: ...
    @staticmethod
    def GetDefaultAvailableSpecies() -> List[str]: ...
    @staticmethod
    def GetDefaultUsedSpecies() -> List[str]: ...

class UIException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class UnhandledExceptionHandler:  # Class
    QuantAppId: int  # static # readonly

    @staticmethod
    def Cleanup() -> None: ...
    @staticmethod
    def HandleConsoleException(e: System.Exception) -> None: ...
    @overload
    @staticmethod
    def Setup(
        enableErrorReporting: bool,
        appId: int,
        appName: str,
        emailAddress: str,
        dumpLogOnNormalExit: bool,
        windowsApplication: bool,
    ) -> None: ...
    @overload
    @staticmethod
    def Setup(
        enableErrorReporting: bool,
        appId: int,
        appName: str,
        titleAppName: str,
        emailAddress: str,
        dumpLogOnNormalExit: bool,
        windowsApplication: bool,
    ) -> None: ...

class Utilities:  # Class
    HelpDataSetFilePath: str  # static # readonly

    @staticmethod
    def VerifyUserForTimeout(
        compliance: ICompliance, mainWindowHandle: System.IntPtr
    ) -> bool: ...
    @staticmethod
    def ShowExceptionMessage(
        parent: System.Windows.Forms.IWin32Window, ex: System.Exception
    ) -> None: ...
    @staticmethod
    def IsPaneVisible(control: System.Windows.Forms.Control) -> bool: ...
    @staticmethod
    def GetAssemblyAttribute(assembly: System.Reflection.Assembly) -> T: ...
    @staticmethod
    def ShowHelpQuantitationDataSet(
        parent: System.Windows.Forms.IWin32Window,
    ) -> None: ...
    @staticmethod
    def SplitMSScanTypes(
        scanTypes: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    @staticmethod
    def GetUnitStringForAxis(
        unit: Agilent.MassSpectrometry.DataAnalysis.DataUnit,
    ) -> str: ...
    @staticmethod
    def DisplayConsoleCopyright(
        asm: System.Reflection.Assembly,
        productRevision: str,
        patchNumber: str,
        writer: System.IO.TextWriter,
    ) -> None: ...
    @staticmethod
    def InitPlotPreferences(
        data: Agilent.MassSpectrometry.DataAnalysis.IFXData,
        prefs: Agilent.MassSpectrometry.DataAnalysis.IPlotPreferences,
    ) -> None: ...
    @staticmethod
    def GetHelpFilePath(filename: str) -> str: ...
    @staticmethod
    def GetParent(mainWindowHandle: System.IntPtr) -> System.IntPtr: ...
    @staticmethod
    def GetApplicationDisplayName(application: str) -> str: ...
    @staticmethod
    def CheckBeingAcquired(dir: str) -> None: ...
    @staticmethod
    def RegisterProduct(parent: System.IntPtr) -> None: ...
    @staticmethod
    def FindKnownExceptions(
        e: System.Exception, knownTypes: List[System.Type]
    ) -> List[System.Exception]: ...
    @staticmethod
    def GetInstrumentTypeDisplayName(instrument: InstrumentType) -> str: ...
    @staticmethod
    def ShowProfile3DBrowser(samplePath: str, mz: float, rt: float) -> None: ...
    @staticmethod
    def GetSubAppDisplayText(
        instrumentType: InstrumentType, application: str, compliance: ICompliance
    ) -> str: ...
    @staticmethod
    def SetLeaseTimeZero() -> None: ...
    @staticmethod
    def ShowUsage(
        parent: System.Windows.Forms.IWin32Window,
        cmdlineType: System.Type,
        rmgr: System.Resources.ResourceManager,
        predesc: str,
        title: str,
        icon: System.Drawing.Icon,
    ) -> None: ...
    @staticmethod
    def IsModal(window: System.Windows.Window) -> bool: ...
    @staticmethod
    def IntegrateSpectrum(
        spectrum: Agilent.MassSpectrometry.DataAnalysis.ISpectrum,
        heightAbsThreshold: float,
        heightPctThreshold: float,
    ) -> Agilent.MassSpectrometry.DataAnalysis.IPeakList: ...
    @staticmethod
    def IsKnownException(
        e: System.Exception, knownTypes: List[System.Type]
    ) -> bool: ...
    @overload
    @staticmethod
    def ShowMessage(
        parent: System.Windows.Forms.IWin32Window,
        message: str,
        title: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...
    @overload
    @staticmethod
    def ShowMessage(
        parent: System.Windows.Forms.IWin32Window,
        message: str,
        title: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
        helpId: int,
    ) -> System.Windows.Forms.DialogResult: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis import (
    IFunction,
    IModificationSpecies,
    SpectralPeak,
    SpectralPeakFinderParameters,
)
from .Agilent.MassSpectrometry.DataAnalysis.MassHunter import (
    IRawSpectrumAccessor,
    SpectraType,
    SpectrumSetMetadata,
)
from .BasicTypes import (
    ChromMetadata,
    CoelutionGroup,
    EICCollection,
    IChromatographyObject,
    ILocation2D,
    IsotopeCluster,
    MfeCompound,
    MSProfile,
    Peak3D,
    PeakList,
    Signal3D,
    XYCollectionLine,
)
from .IsotopePatternCalculator import IIsotopePattern
from .Mathematics import RangeDouble
from .Mfe import IsotopeCharacter

# Stubs for namespace: CommonAlgorithms

class BaselineFinder:  # Class
    def __init__(
        self, shootingLengthForward: IFunction, shootingLengthBackward: IFunction
    ) -> None: ...
    def DetermineBaseline(self, data: List[float]) -> List[float]: ...

class BaselineFinderMSProfile:  # Class
    def __init__(self, shootingLength: IFunction) -> None: ...

    ShootingLength: float  # static # readonly

    def GetBaseline(self, spectrum: MSProfile) -> MSProfile: ...

class ChromObjectGrouper:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Group(objectsWithRT: List[Any], targetWidth0: IFunction) -> List[Any]: ...

    # Nested Types

    class PeakGroup(
        List[IChromatographyObject],
        System.Collections.Generic.List[IChromatographyObject],
        Iterable[Any],
        Sequence[IChromatographyObject],
        Iterable[IChromatographyObject],
        Sequence[Any],
        List[Any],
    ):  # Class
        def __init__(self, count: int) -> None: ...

        MaxRT: float  # readonly
        MinRT: float  # readonly
        RT: float  # readonly

        # Nested Types

        class Comparer(
            System.Collections.Generic.IComparer[
                CommonAlgorithms.ChromObjectGrouper.PeakGroup
            ],
            System.Collections.IComparer,
        ):  # Class
            def __init__(self) -> None: ...
            @overload
            def Compare(self, o1: Any, o2: Any) -> int: ...
            @overload
            def Compare(
                self,
                g1: CommonAlgorithms.ChromObjectGrouper.PeakGroup,
                g2: CommonAlgorithms.ChromObjectGrouper.PeakGroup,
            ) -> int: ...

class CompoundGrouper:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def CalculateAveRTDeviation(compounds: List[Any]) -> float: ...
    @overload
    @staticmethod
    def GroupCompounds(
        compounds: List[Any], maxGroupSread: float
    ) -> List[CoelutionGroup]: ...
    @overload
    @staticmethod
    def GroupCompounds(
        compounds: List[MfeCompound], maxGroupSread: float
    ) -> List[CoelutionGroup]: ...

class CompoundMatcher:  # Class
    def __init__(self, formulas: Sequence[str]) -> None: ...
    def GetFormula(self, mass: float, retentionTime: float) -> str: ...
    def ContainsFormula(self, formula: str) -> bool: ...

class ConstScanRateEICProcessor(CommonAlgorithms.BaselineFinder):  # Class
    def __init__(
        self, rtPeakWidth: float, rts: List[float], scanRate: float
    ) -> None: ...
    def DetermineBaseline(self, data: List[float]) -> List[float]: ...

    # Nested Types

    class PeakWidthModel(IFunction):  # Class
        def __init__(
            self,
            lengthInTime: float,
            scanRate: float,
            rts: List[float],
            isForward: bool,
        ) -> None: ...

        IsConstant: bool  # readonly

        def Y(self, x: float) -> float: ...

class DuplicatedPeakChecker:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Find(sortedMzs: List[float], heights: List[float]) -> Sequence[int]: ...

class FeatureCorrelator:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def CorrelateFeatures(
        signals: List[List[Any]],
        maxRTShift: IFunction,
        maxMassShift: IFunction,
        rtRange: RangeDouble,
        mzRange: RangeDouble,
    ) -> List[Any]: ...

class IntensityMatcher:  # Class
    def __init__(
        self,
        intensitiesSynthetics: List[float],
        intensitiesObserved: List[float],
        uncertainties: List[float],
    ) -> None: ...
    def CalculateMatchingScore(
        self, method: CommonAlgorithms.IntensityMatcher.Method, heightError: float
    ) -> float: ...

    # Nested Types

    class Method(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        ModifiedCC: CommonAlgorithms.IntensityMatcher.Method = ...  # static # readonly
        Probabilty: CommonAlgorithms.IntensityMatcher.Method = ...  # static # readonly

class IsotopeGrouper1:  # Class
    @overload
    def __init__(
        self,
        mzErrorFunction: ChromMetadata.MZError,
        userParameters: IsotopeCharacter,
        globalMinHeight: float,
        maxZ: int,
    ) -> None: ...
    @overload
    def __init__(
        self,
        mzErrorFunction: ChromMetadata.MZError,
        userParameters: IsotopeCharacter,
        globalMinHeight: float,
        precursorChargeCount: int,
        precursorMz: float,
        ms2DataWithPartialIsolationWindow: bool,
    ) -> None: ...

    Delta: float  # static # readonly

    @overload
    def Run(self, peaks: PeakList, maxZ: int) -> List[IsotopeCluster]: ...
    @overload
    def Run(
        self, peaks: PeakList
    ) -> System.Collections.Generic.List[IsotopeCluster]: ...
    @staticmethod
    def LocationError(mzError: ChromMetadata.MZError, mz: float) -> float: ...

class IsotopePatternMatcher:  # Class
    @overload
    def __init__(
        self, mzAccurayFunction: IFunction, relativeIntensityAccuracy: float
    ) -> None: ...
    @overload
    def __init__(
        self,
        mzAccurayFunction: IFunction,
        relativeIntensityAccuracy: float,
        scoreSinglePeak: bool,
        useProductScoring: bool,
        avgMzAbundPower: int,
    ) -> None: ...
    def CalculateMatchingScore(
        self,
        synthetic: PeakList,
        observed: PeakList,
        chargeCount: int,
        useMzScore: bool,
        useNewSpacingScoring: bool,
        averageMzScore: float,
        intensityScore: float,
        spacingScore: float,
        averageMzError: float,
        heightError: float,
        s1Error: float,
        s2Error: float,
    ) -> float: ...

class IsotopeScoreCalculator:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetScore(
        formula: str,
        peaks: List[SpectralPeak],
        numberOfTheoreticalPeakToCalculate: int,
        useLowestMzOnly: bool,
        ionSpecies: IModificationSpecies,
        massAccuracyCoeffients: List[float],
        relativeIntensityAccuracy: float,
        mzScore: float,
        intensityScore: float,
        spacingScore: float,
    ) -> float: ...
    @staticmethod
    def CalculateSyntheticPeaks(
        formula: str,
        z: int,
        ionSpecies: IModificationSpecies,
        maxPeakCountToUse: int,
        isotopeDistribution: IIsotopePattern,
    ) -> PeakList: ...

class Location2DGrid:  # Class
    def __init__(
        self,
        data: List[Any],
        xRange: RangeDouble,
        yRange: RangeDouble,
        gridSize: CommonAlgorithms.Location2DGrid.GridSize,
    ) -> None: ...

    AllPeaks: List[Any]  # readonly

    def Add(self, newPeak: ILocation2D) -> None: ...
    @overload
    def Neighbors(
        self, pk: ILocation2D
    ) -> System.Collections.Generic.List[ILocation2D]: ...
    @overload
    def Neighbors(
        self, mzStart: int, mzEnd: int, rtStart: int, rtEnd: int
    ) -> System.Collections.Generic.List[ILocation2D]: ...
    @overload
    def Neighbors(
        self, mz: float, rt: float, maxMzShift: float, maxRtShift: float
    ) -> System.Collections.Generic.List[ILocation2D]: ...
    def Remove(self, pk: ILocation2D) -> None: ...

    # Nested Types

    class GridSize:  # Struct
        def __init__(self, x: float, y: float) -> None: ...

        X: float
        Y: float

class MassErrorToSpacingErroConvertor:  # Class
    def __init__(self) -> None: ...

    Factor: float  # static # readonly

class MaxChargeManager:  # Class
    @overload
    def __init__(self, maxChargeCount: int) -> None: ...
    @overload
    def __init__(self, precursorMz: float, precursorChargeCount: int) -> None: ...

class NoiseLevelFinder:  # Class
    def __init__(self, data: List[float]) -> None: ...

    NoiseFunction: IFunction  # readonly

    def ThresholdLevel(self, threshold: float) -> IFunction: ...

class Peak3DQualityScoreAssigner:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def QCScore(pk: Peak3D, averagePeakWidth: float) -> float: ...

class PeakFinderParallelizer:  # Class
    @overload
    def __init__(
        self,
        spectrumAccessor: IRawSpectrumAccessor,
        rtRange: RangeDouble,
        mzRange: RangeDouble,
        metadata: ChromMetadata,
        rtHalfTaperSpan: float,
        aproriRTPeakWidth: float,
        parameters: SpectralPeakFinderParameters,
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    PeakLists: List[PeakList]  # readonly
    StepCount: int  # readonly

    def StepIt(self, stepIndex: int) -> None: ...
    def SetData(
        self,
        spectrumAccessor: IRawSpectrumAccessor,
        rtRange: RangeDouble,
        mzRange: RangeDouble,
        metadata: ChromMetadata,
        rtHalfTaperSpan: float,
        aproriRTPeakWidth: float,
        parameters: SpectralPeakFinderParameters,
    ) -> None: ...

class PeakListAligner:  # Class
    def __init__(
        self,
        synthetic: PeakList,
        observed: PeakList,
        mzAccuray: float,
        alignByFirstPeak: bool,
    ) -> None: ...
    def GetPairedIntensities(
        self, intensityA: List[float], intensityB: List[float]
    ) -> None: ...
    def GetPairedPeaks(self, peaksA: PeakList, peaksB: PeakList) -> bool: ...
    def GetPaddedPeaks(self, peaksA: PeakList, peaksB: PeakList) -> None: ...

class Probability:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetPaddedProbabilityDensity(
        originalDensity: float, minDensity: float
    ) -> float: ...

class ProfileSpectraReaderEmptySpectraFree(IRawSpectrumAccessor):  # Class
    def __init__(self, rawReader: IRawSpectrumAccessor) -> None: ...

    FullSaturationLevel: float  # readonly
    Metadata: SpectrumSetMetadata  # readonly
    ScanCalibCoefficients: List[float]  # readonly
    ScanFirstBinIndex: int  # readonly
    ScanFirstXValue: float  # readonly
    ScanProfileIntensities: List[float]  # readonly
    ScanRetentionTimes: List[float]  # readonly
    SpectraType: SpectraType  # readonly
    TicIntensities: List[float]  # readonly

    def Close(self) -> None: ...
    def GetPeakList(
        self, mz: List[float], heights: List[float], errorCode: List[int]
    ) -> None: ...
    def Open(self) -> None: ...
    def UpdateScan(self, scanIndex: int, minMZ: float, maxMZ: float) -> None: ...

class RtPeakWidthEstimator:  # Class
    def __init__(self) -> None: ...
    @overload
    @staticmethod
    def MeasurePeakWidth(
        eics: EICCollection, retentionTimes: List[float], maxHeight: float
    ) -> float: ...
    @overload
    @staticmethod
    def MeasurePeakWidth(profileSpectraReader: IRawSpectrumAccessor) -> float: ...

class SmootherMSProfile:  # Class
    def __init__(self, smoothingLenth: IFunction, strengths: List[float]) -> None: ...

    SmoothingLength: float  # static # readonly

    @overload
    def Smooth(self, raw: MSProfile) -> MSProfile: ...
    @overload
    def Smooth(self, raw: List[float]) -> List[float]: ...

class XYCollectionLineBinner:  # Class
    def __init__(self) -> None: ...
    @overload
    @staticmethod
    def Run(data: XYCollectionLine, minMZ: float) -> None: ...
    @overload
    @staticmethod
    def Run(
        signals: System.Collections.Generic.List[Signal3D],
        metaData: ChromMetadata,
        minMZ: float,
    ) -> EICCollection: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Compliance import ILogonParameters

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Report

class ReportGeneratorCommandLine(ILogonParameters):  # Class
    def __init__(self) -> None: ...

    AccountName: str
    BatchFileName: str
    BatchPath: str
    CompoundIds: str
    ConnectionTicket: str
    Domain: str
    EncryptedPassword: str
    FixedGraphicsFile: str
    Help: bool
    InstrumentType: str
    Local: bool
    NoGraphics: bool
    NoLogo: bool
    OutputExcelFile: str
    OutputPath: str
    Password: str
    Printer: str
    PublishFormat: str
    Queue: bool
    ReportFileName: str
    SampleIds: str
    ScriptFile: str
    Server: str
    SettingsFile: str
    SingleSampleMode: bool
    Template: str
    User: str
    _Password: System.Security.SecureString  # readonly

    def Run(self) -> int: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
TInput = TypeVar("TInput")
TOutput = TypeVar("TOutput")

# Stubs for namespace: System.Runtime.CompilerServices

class ArrayTypeNameAliasAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, typeName: str, alias: str) -> None: ...

    Alias: str
    TypeName: str

class ClientNameAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, name: str) -> None: ...

    AllowConflict: bool
    AllowObfuscation: bool
    ClientName: str

class ConvertToInstanceInvocationAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    @overload
    def __init__(self, name: str, instanceIndex: int) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

    Index: int
    Name: str

class DontHideAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class DontObfuscateAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

class DynamicDefaultValueAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class EncapsulatePrivateFieldsAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

class HideAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class IWidgetExternalObject(object):  # Interface
    InternalObject: Any  # readonly

class IWidgetInternalObject(object):  # Interface
    ExternalObject: Any  # readonly

class JAVAClientNameAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.ClientNameAttribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class JAVADontHideAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.DontHideAttribute,
):  # Class
    def __init__(self) -> None: ...

class JAVAMainWidgetAttribute(
    System.Runtime.CompilerServices.MainWidgetAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class JAVASuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class JAVASuppressWidgetMemberCopyAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberCopyAttribute,
):  # Class
    def __init__(self) -> None: ...

class JAVAWeakAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

class JAVAWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class JAVAWidgetDefaultBooleanAttribute(
    System.Runtime.CompilerServices.WidgetDefaultBooleanAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    def __init__(self, value_: bool) -> None: ...

class JAVAWidgetDefaultNumberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetDefaultNumberAttribute,
):  # Class
    def __init__(self, value_: float) -> None: ...

class JAVAWidgetDefaultStringAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetDefaultStringAttribute,
):  # Class
    def __init__(self, value_: str) -> None: ...

class JAVAWidgetModuleAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetModuleAttribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class JSClientNameAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.ClientNameAttribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class JSMainWidgetAttribute(
    System.Runtime.CompilerServices.MainWidgetAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class JSSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class JSSuppressWidgetMemberCopyAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberCopyAttribute,
):  # Class
    def __init__(self) -> None: ...

class JSWeakAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

class JSWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class JSWidgetDefaultBooleanAttribute(
    System.Runtime.CompilerServices.WidgetDefaultBooleanAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    def __init__(self, value_: bool) -> None: ...

class JSWidgetDefaultNumberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetDefaultNumberAttribute,
):  # Class
    def __init__(self, value_: float) -> None: ...

class JSWidgetDefaultStringAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetDefaultStringAttribute,
):  # Class
    def __init__(self, value_: str) -> None: ...

class JSWidgetModuleAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetModuleAttribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class JSWidgetSnippetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, exampleValue: str, isCode: bool) -> None: ...
    @overload
    def __init__(self, exampleValue: bool) -> None: ...
    @overload
    def __init__(self, exampleValue: float) -> None: ...

    BeforeInitializeCode: str
    EventDelegateCode: str
    OtherInitializeProperties: List[str]

class LogicalChildrenAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class MainWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

    Name: str

class ManuallyReleasedAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

class MvcEnumSetStringEnumAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class MvcSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class NativeWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class OBJCClientNameAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.ClientNameAttribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class OBJCMainWidgetAttribute(
    System.Runtime.CompilerServices.MainWidgetAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class OBJCSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class OBJCSuppressWidgetMemberCopyAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberCopyAttribute,
):  # Class
    def __init__(self) -> None: ...

class OBJCWeakAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

class OBJCWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class OBJCWidgetDefaultBooleanAttribute(
    System.Runtime.CompilerServices.WidgetDefaultBooleanAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    def __init__(self, value_: bool) -> None: ...

class OBJCWidgetDefaultNumberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetDefaultNumberAttribute,
):  # Class
    def __init__(self, value_: float) -> None: ...

class OBJCWidgetDefaultStringAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetDefaultStringAttribute,
):  # Class
    def __init__(self, value_: str) -> None: ...

class OBJCWidgetModuleAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetModuleAttribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class ObjCFrameworkNameAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, frameworkName: str) -> None: ...

    FrameworkName: str

class ObjCUseCArrayAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    @overload
    def __init__(self, name: str) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Name: str

class ReferenceGlobalShortNamesAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class ShortNamePrefixAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, prefix: str) -> None: ...

    Prefix: str

class SuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class SuppressWidgetMemberCopyAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class TSClientNameAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.ClientNameAttribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class TSIgnoreAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    def __init__(self) -> None: ...

class TSSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class TSWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class TranslatedTypePrefixAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    @overload
    def __init__(self, prefix: str, typeNamespace: str) -> None: ...
    @overload
    def __init__(self, prefix: str) -> None: ...

    Prefix: str
    TypeNamespace: str

class TreatAsDPAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class TreatAsNumberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class TreatAsPXAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class TreatAsSPAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class UseSimpleObjCMethodNamingAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class UwpWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class UwpWidgetMemberNameAttribute(
    System.Runtime.CompilerServices.WidgetMemberNameAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class UwpWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class WFSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class WFWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class WFWidgetCategoryAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, category: str) -> None: ...

class WFWidgetDesignTimeHiddenAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class WFWidgetEventManagerAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(
        self,
        enumPrefix: str,
        canAccessInternals: bool,
        includeMouseElementEvents: bool,
        includeGestureEvents: bool,
    ) -> None: ...

class WFWidgetEventManagerGroupAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, eventGroupName: str) -> None: ...

class WFWidgetMemberNameAttribute(
    System.Runtime.CompilerServices.WidgetMemberNameAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class WFWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class WeakAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

class WfWidgetDescriptionAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, generateDescription: bool) -> None: ...

class WfWidgetPropertyChangeIdAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, enumName: str, internalEnumFullName: str = ...) -> None: ...

class WidgetAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

    Name: str  # readonly

class WidgetAttributeBase(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    ...

class WidgetDefaultBooleanAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, value_: bool) -> None: ...

    Value: bool

class WidgetDefaultNumberAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, value_: float) -> None: ...

    Value: float

class WidgetDefaultStringAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, value_: str) -> None: ...

    Value: str

class WidgetDependencyPropertyAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, isDependencyProperty: bool) -> None: ...

class WidgetElementAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class WidgetFlattenedMemberInfoAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, propertyNamePattern: str = ...) -> None: ...

class WidgetFontPropertyAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(
        self,
        propertyPrefix: str,
        simpleCommentDescription: str,
        defaultFontFamily: str = ...,
        defaultFontSize: float = ...,
        defaultBold: bool = ...,
        defaultItalic: bool = ...,
    ) -> None: ...

class WidgetIgnoreDependsAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, name: str) -> None: ...

    Name: str

class WidgetIncludeDependsAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, name: str) -> None: ...

    Name: str

class WidgetMemberNameAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, name: str) -> None: ...

    Name: str

class WidgetModuleAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, name: str) -> None: ...

    Name: str

class WidgetModuleExclusionParentAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, name: str) -> None: ...

    Name: str

class WidgetModuleParentAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, name: str) -> None: ...

    Name: str
    RestrictToSameAssembly: bool

class WidgetNamespaceAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class WidgetPropertyToFlattenAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(
        self, propertyPrefix: str, propertiesToSuppress: List[str] = ...
    ) -> None: ...

class WidgetUniquePrefixAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, prefix: str) -> None: ...

class WidgetUtilities:  # Class
    @staticmethod
    def ToExternalObject(internalObject: Any) -> Any: ...
    @staticmethod
    def FromExternalObject(externalObject: Any) -> Any: ...
    @overload
    @staticmethod
    def Convert(
        input: System.Nullable[TInput], conversion: System.Func[TInput, TOutput]
    ) -> System.Nullable[TOutput]: ...
    @overload
    @staticmethod
    def Convert(
        input: List[TInput], converter: System.Func[TInput, TOutput]
    ) -> List[TOutput]: ...

class WpfSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class WpfWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class XamAndroidSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class XamAndroidWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class XamAndroidWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class XamSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class XamTwoWayPropertyAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, isTwoWay: bool = ...) -> None: ...

class XamWPSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class XamWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class XamWidgetMemberNameAttribute(
    System.Runtime.CompilerServices.WidgetMemberNameAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    def __init__(self, name: str) -> None: ...

class XamWrapperAndroidWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class XamWrapperAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class XamWrapperCreateDefaultValueAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class XamWrapperIOSWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class XamWrapperSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class XamWrapperUwpWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class XamWrapperWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class XamWrapperWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...

class XamiOSEnumNameAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self, value_: str) -> None: ...

    Value: str

class XamiOSSuppressWidgetMemberAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.SuppressWidgetMemberAttribute,
):  # Class
    def __init__(self) -> None: ...

class XamiOSTreatAsDoubleAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class XamiOSTreatAsFloatAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttributeBase,
):  # Class
    def __init__(self) -> None: ...

class XamiOSWidgetAttribute(
    System.Runtime.InteropServices._Attribute,
    System.Runtime.CompilerServices.WidgetAttribute,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

class XamiOSWidgetNamespaceAttribute(
    System.Runtime.CompilerServices.WidgetNamespaceAttribute,
    System.Runtime.InteropServices._Attribute,
):  # Class
    @overload
    def __init__(self, namespace: str) -> None: ...
    @overload
    def __init__(self, namespace: str, sourceNamespace: str) -> None: ...
